import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AlbListenerConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly certificateArn?: string;
    /**
     * @stability stable
     */
    readonly loadBalancerArn: string;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * @stability stable
     */
    readonly sslPolicy?: string;
    /**
     * default_action block.
     *
     * @stability stable
     */
    readonly defaultAction: AlbListenerDefaultAction[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: AlbListenerTimeouts;
}
/**
 * @stability stable
 */
export interface AlbListenerDefaultActionAuthenticateCognito {
    /**
     * @stability stable
     */
    readonly authenticationRequestExtraParams?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly onUnauthenticatedRequest?: string;
    /**
     * @stability stable
     */
    readonly scope?: string;
    /**
     * @stability stable
     */
    readonly sessionCookieName?: string;
    /**
     * @stability stable
     */
    readonly sessionTimeout?: number;
    /**
     * @stability stable
     */
    readonly userPoolArn: string;
    /**
     * @stability stable
     */
    readonly userPoolClientId: string;
    /**
     * @stability stable
     */
    readonly userPoolDomain: string;
}
/**
 * @stability stable
 */
export interface AlbListenerDefaultActionAuthenticateOidc {
    /**
     * @stability stable
     */
    readonly authenticationRequestExtraParams?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly authorizationEndpoint: string;
    /**
     * @stability stable
     */
    readonly clientId: string;
    /**
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * @stability stable
     */
    readonly issuer: string;
    /**
     * @stability stable
     */
    readonly onUnauthenticatedRequest?: string;
    /**
     * @stability stable
     */
    readonly scope?: string;
    /**
     * @stability stable
     */
    readonly sessionCookieName?: string;
    /**
     * @stability stable
     */
    readonly sessionTimeout?: number;
    /**
     * @stability stable
     */
    readonly tokenEndpoint: string;
    /**
     * @stability stable
     */
    readonly userInfoEndpoint: string;
}
/**
 * @stability stable
 */
export interface AlbListenerDefaultActionFixedResponse {
    /**
     * @stability stable
     */
    readonly contentType: string;
    /**
     * @stability stable
     */
    readonly messageBody?: string;
    /**
     * @stability stable
     */
    readonly statusCode?: string;
}
/**
 * @stability stable
 */
export interface AlbListenerDefaultActionForwardStickiness {
    /**
     * @stability stable
     */
    readonly duration: number;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
}
/**
 * @stability stable
 */
export interface AlbListenerDefaultActionForwardTargetGroup {
    /**
     * @stability stable
     */
    readonly arn: string;
    /**
     * @stability stable
     */
    readonly weight?: number;
}
/**
 * @stability stable
 */
export interface AlbListenerDefaultActionForward {
    /**
     * stickiness block.
     *
     * @stability stable
     */
    readonly stickiness?: AlbListenerDefaultActionForwardStickiness[];
    /**
     * target_group block.
     *
     * @stability stable
     */
    readonly targetGroup: AlbListenerDefaultActionForwardTargetGroup[];
}
/**
 * @stability stable
 */
export interface AlbListenerDefaultActionRedirect {
    /**
     * @stability stable
     */
    readonly host?: string;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly port?: string;
    /**
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * @stability stable
     */
    readonly query?: string;
    /**
     * @stability stable
     */
    readonly statusCode: string;
}
/**
 * @stability stable
 */
export interface AlbListenerDefaultAction {
    /**
     * @stability stable
     */
    readonly order?: number;
    /**
     * @stability stable
     */
    readonly targetGroupArn?: string;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * authenticate_cognito block.
     *
     * @stability stable
     */
    readonly authenticateCognito?: AlbListenerDefaultActionAuthenticateCognito[];
    /**
     * authenticate_oidc block.
     *
     * @stability stable
     */
    readonly authenticateOidc?: AlbListenerDefaultActionAuthenticateOidc[];
    /**
     * fixed_response block.
     *
     * @stability stable
     */
    readonly fixedResponse?: AlbListenerDefaultActionFixedResponse[];
    /**
     * forward block.
     *
     * @stability stable
     */
    readonly forward?: AlbListenerDefaultActionForward[];
    /**
     * redirect block.
     *
     * @stability stable
     */
    readonly redirect?: AlbListenerDefaultActionRedirect[];
}
/**
 * @stability stable
 */
export interface AlbListenerTimeouts {
    /**
     * @stability stable
     */
    readonly read?: string;
}
/**
 * @stability stable
 */
export declare class AlbListener extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AlbListenerConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _certificateArn?;
    /**
     * @stability stable
     */
    get certificateArn(): string;
    /**
     * @stability stable
     */
    set certificateArn(value: string);
    /**
     * @stability stable
     */
    resetCertificateArn(): void;
    /**
     * @stability stable
     */
    get certificateArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _loadBalancerArn;
    /**
     * @stability stable
     */
    get loadBalancerArn(): string;
    /**
     * @stability stable
     */
    set loadBalancerArn(value: string);
    /**
     * @stability stable
     */
    get loadBalancerArnInput(): string;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
    private _protocol?;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    set protocol(value: string);
    /**
     * @stability stable
     */
    resetProtocol(): void;
    /**
     * @stability stable
     */
    get protocolInput(): string | undefined;
    private _sslPolicy?;
    /**
     * @stability stable
     */
    get sslPolicy(): string;
    /**
     * @stability stable
     */
    set sslPolicy(value: string);
    /**
     * @stability stable
     */
    resetSslPolicy(): void;
    /**
     * @stability stable
     */
    get sslPolicyInput(): string | undefined;
    private _defaultAction;
    /**
     * @stability stable
     */
    get defaultAction(): AlbListenerDefaultAction[];
    /**
     * @stability stable
     */
    set defaultAction(value: AlbListenerDefaultAction[]);
    /**
     * @stability stable
     */
    get defaultActionInput(): AlbListenerDefaultAction[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AlbListenerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AlbListenerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AlbListenerTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
