import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AppsyncGraphqlApiConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly authenticationType: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly schema?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly xrayEnabled?: boolean;
    /**
     * additional_authentication_provider block.
     *
     * @stability stable
     */
    readonly additionalAuthenticationProvider?: AppsyncGraphqlApiAdditionalAuthenticationProvider[];
    /**
     * log_config block.
     *
     * @stability stable
     */
    readonly logConfig?: AppsyncGraphqlApiLogConfig[];
    /**
     * openid_connect_config block.
     *
     * @stability stable
     */
    readonly openidConnectConfig?: AppsyncGraphqlApiOpenidConnectConfig[];
    /**
     * user_pool_config block.
     *
     * @stability stable
     */
    readonly userPoolConfig?: AppsyncGraphqlApiUserPoolConfig[];
}
/**
 * @stability stable
 */
export interface AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig {
    /**
     * @stability stable
     */
    readonly authTtl?: number;
    /**
     * @stability stable
     */
    readonly clientId?: string;
    /**
     * @stability stable
     */
    readonly iatTtl?: number;
    /**
     * @stability stable
     */
    readonly issuer: string;
}
/**
 * @stability stable
 */
export interface AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig {
    /**
     * @stability stable
     */
    readonly appIdClientRegex?: string;
    /**
     * @stability stable
     */
    readonly awsRegion?: string;
    /**
     * @stability stable
     */
    readonly userPoolId: string;
}
/**
 * @stability stable
 */
export interface AppsyncGraphqlApiAdditionalAuthenticationProvider {
    /**
     * @stability stable
     */
    readonly authenticationType: string;
    /**
     * openid_connect_config block.
     *
     * @stability stable
     */
    readonly openidConnectConfig?: AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig[];
    /**
     * user_pool_config block.
     *
     * @stability stable
     */
    readonly userPoolConfig?: AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig[];
}
/**
 * @stability stable
 */
export interface AppsyncGraphqlApiLogConfig {
    /**
     * @stability stable
     */
    readonly cloudwatchLogsRoleArn: string;
    /**
     * @stability stable
     */
    readonly excludeVerboseContent?: boolean;
    /**
     * @stability stable
     */
    readonly fieldLogLevel: string;
}
/**
 * @stability stable
 */
export interface AppsyncGraphqlApiOpenidConnectConfig {
    /**
     * @stability stable
     */
    readonly authTtl?: number;
    /**
     * @stability stable
     */
    readonly clientId?: string;
    /**
     * @stability stable
     */
    readonly iatTtl?: number;
    /**
     * @stability stable
     */
    readonly issuer: string;
}
/**
 * @stability stable
 */
export interface AppsyncGraphqlApiUserPoolConfig {
    /**
     * @stability stable
     */
    readonly appIdClientRegex?: string;
    /**
     * @stability stable
     */
    readonly awsRegion?: string;
    /**
     * @stability stable
     */
    readonly defaultAction: string;
    /**
     * @stability stable
     */
    readonly userPoolId: string;
}
/**
 * @stability stable
 */
export declare class AppsyncGraphqlApi extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppsyncGraphqlApiConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _authenticationType;
    /**
     * @stability stable
     */
    get authenticationType(): string;
    /**
     * @stability stable
     */
    set authenticationType(value: string);
    /**
     * @stability stable
     */
    get authenticationTypeInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _schema?;
    /**
     * @stability stable
     */
    get schema(): string;
    /**
     * @stability stable
     */
    set schema(value: string);
    /**
     * @stability stable
     */
    resetSchema(): void;
    /**
     * @stability stable
     */
    get schemaInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    uris(key: string): string;
    private _xrayEnabled?;
    /**
     * @stability stable
     */
    get xrayEnabled(): boolean;
    /**
     * @stability stable
     */
    set xrayEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetXrayEnabled(): void;
    /**
     * @stability stable
     */
    get xrayEnabledInput(): boolean | undefined;
    private _additionalAuthenticationProvider?;
    /**
     * @stability stable
     */
    get additionalAuthenticationProvider(): AppsyncGraphqlApiAdditionalAuthenticationProvider[];
    /**
     * @stability stable
     */
    set additionalAuthenticationProvider(value: AppsyncGraphqlApiAdditionalAuthenticationProvider[]);
    /**
     * @stability stable
     */
    resetAdditionalAuthenticationProvider(): void;
    /**
     * @stability stable
     */
    get additionalAuthenticationProviderInput(): AppsyncGraphqlApiAdditionalAuthenticationProvider[] | undefined;
    private _logConfig?;
    /**
     * @stability stable
     */
    get logConfig(): AppsyncGraphqlApiLogConfig[];
    /**
     * @stability stable
     */
    set logConfig(value: AppsyncGraphqlApiLogConfig[]);
    /**
     * @stability stable
     */
    resetLogConfig(): void;
    /**
     * @stability stable
     */
    get logConfigInput(): AppsyncGraphqlApiLogConfig[] | undefined;
    private _openidConnectConfig?;
    /**
     * @stability stable
     */
    get openidConnectConfig(): AppsyncGraphqlApiOpenidConnectConfig[];
    /**
     * @stability stable
     */
    set openidConnectConfig(value: AppsyncGraphqlApiOpenidConnectConfig[]);
    /**
     * @stability stable
     */
    resetOpenidConnectConfig(): void;
    /**
     * @stability stable
     */
    get openidConnectConfigInput(): AppsyncGraphqlApiOpenidConnectConfig[] | undefined;
    private _userPoolConfig?;
    /**
     * @stability stable
     */
    get userPoolConfig(): AppsyncGraphqlApiUserPoolConfig[];
    /**
     * @stability stable
     */
    set userPoolConfig(value: AppsyncGraphqlApiUserPoolConfig[]);
    /**
     * @stability stable
     */
    resetUserPoolConfig(): void;
    /**
     * @stability stable
     */
    get userPoolConfigInput(): AppsyncGraphqlApiUserPoolConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
