import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AwsProviderConfig {
    /**
     * The access key for API operations.
     *
     * You can retrieve this
     * from the 'Security & Credentials' section of the AWS console.
     *
     * @stability stable
     */
    readonly accessKey?: string;
    /**
     * @stability stable
     */
    readonly allowedAccountIds?: string[];
    /**
     * @stability stable
     */
    readonly forbiddenAccountIds?: string[];
    /**
     * Explicitly allow the provider to perform "insecure" SSL requests.
     *
     * If omitted,default value is `false`
     *
     * @stability stable
     */
    readonly insecure?: boolean;
    /**
     * The maximum number of times an AWS API request is being executed.
     *
     * If the API request still fails, an error is
     * thrown.
     *
     * @stability stable
     */
    readonly maxRetries?: number;
    /**
     * The profile for API operations.
     *
     * If not set, the default profile
     * created with `aws configure` will be used.
     *
     * @stability stable
     */
    readonly profile?: string;
    /**
     * The region where AWS operations will take place.
     *
     * Examples
     * are us-east-1, us-west-2, etc.
     *
     * @stability stable
     */
    readonly region: string;
    /**
     * Set this to true to force the request to use path-style addressing, i.e., http://s3.amazonaws.com/BUCKET/KEY. By default, the S3 client will use virtual hosted bucket addressing when possible (http://BUCKET.s3.amazonaws.com/KEY). Specific to the Amazon S3 service.
     *
     * @stability stable
     */
    readonly s3ForcePathStyle?: boolean;
    /**
     * The secret key for API operations.
     *
     * You can retrieve this
     * from the 'Security & Credentials' section of the AWS console.
     *
     * @stability stable
     */
    readonly secretKey?: string;
    /**
     * The path to the shared credentials file.
     *
     * If not set
     * this defaults to ~/.aws/credentials.
     *
     * @stability stable
     */
    readonly sharedCredentialsFile?: string;
    /**
     * Skip the credentials validation via STS API.
     *
     * Used for AWS API implementations that do not have STS available/implemented.
     *
     * @stability stable
     */
    readonly skipCredentialsValidation?: boolean;
    /**
     * Skip getting the supported EC2 platforms.
     *
     * Used by users that don't have ec2:DescribeAccountAttributes permissions.
     *
     * @stability stable
     */
    readonly skipGetEc2Platforms?: boolean;
    /**
     * @stability stable
     */
    readonly skipMetadataApiCheck?: boolean;
    /**
     * Skip static validation of region name.
     *
     * Used by users of alternative AWS-like APIs or users w/ access to regions that are not public (yet).
     *
     * @stability stable
     */
    readonly skipRegionValidation?: boolean;
    /**
     * Skip requesting the account ID.
     *
     * Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
     *
     * @stability stable
     */
    readonly skipRequestingAccountId?: boolean;
    /**
     * session token.
     *
     * A session token is only required if you are
     * using temporary security credentials.
     *
     * @stability stable
     */
    readonly token?: string;
    /**
     * Alias name.
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * assume_role block.
     *
     * @stability stable
     */
    readonly assumeRole?: AwsProviderAssumeRole[];
    /**
     * default_tags block.
     *
     * @stability stable
     */
    readonly defaultTags?: AwsProviderDefaultTags[];
    /**
     * endpoints block.
     *
     * @stability stable
     */
    readonly endpoints?: AwsProviderEndpoints[];
    /**
     * ignore_tags block.
     *
     * @stability stable
     */
    readonly ignoreTags?: AwsProviderIgnoreTags[];
}
/**
 * @stability stable
 */
export interface AwsProviderAssumeRole {
    /**
     * Seconds to restrict the assume role session duration.
     *
     * @stability stable
     */
    readonly durationSeconds?: number;
    /**
     * Unique identifier that might be required for assuming a role in another account.
     *
     * @stability stable
     */
    readonly externalId?: string;
    /**
     * IAM Policy JSON describing further restricting permissions for the IAM Role being assumed.
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * Amazon Resource Names (ARNs) of IAM Policies describing further restricting permissions for the IAM Role being assumed.
     *
     * @stability stable
     */
    readonly policyArns?: string[];
    /**
     * Amazon Resource Name of an IAM Role to assume prior to making API calls.
     *
     * @stability stable
     */
    readonly roleArn?: string;
    /**
     * Identifier for the assumed role session.
     *
     * @stability stable
     */
    readonly sessionName?: string;
    /**
     * Assume role session tags.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Assume role session tag keys to pass to any subsequent sessions.
     *
     * @stability stable
     */
    readonly transitiveTagKeys?: string[];
}
/**
 * @stability stable
 */
export interface AwsProviderDefaultTags {
    /**
     * Resource tags to default across all resources.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface AwsProviderEndpoints {
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly accessanalyzer?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly acm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly acmpca?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly amplify?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly apigateway?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly applicationautoscaling?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly applicationinsights?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly appmesh?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly appstream?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly appsync?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly athena?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly auditmanager?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly autoscaling?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly autoscalingplans?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly backup?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly batch?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly budgets?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloud9?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloudformation?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloudfront?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloudhsm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloudsearch?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloudtrail?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloudwatch?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloudwatchevents?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cloudwatchlogs?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly codeartifact?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly codebuild?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly codecommit?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly codedeploy?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly codepipeline?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly codestarconnections?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cognitoidentity?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cognitoidp?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly configservice?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly connect?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly cur?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly dataexchange?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly datapipeline?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly datasync?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly dax?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly devicefarm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly directconnect?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly dlm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly dms?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly docdb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ds?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly dynamodb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ec2?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ecr?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ecrpublic?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ecs?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly efs?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly eks?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly elasticache?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly elasticbeanstalk?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly elastictranscoder?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly elb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly emr?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly emrcontainers?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly es?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly firehose?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly fms?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly forecast?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly fsx?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly gamelift?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly glacier?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly globalaccelerator?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly glue?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly greengrass?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly guardduty?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly iam?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly identitystore?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly imagebuilder?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly inspector?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly iot?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly iotanalytics?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly iotevents?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly kafka?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly kinesis?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly kinesisanalytics?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly kinesisanalyticsv2?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly kinesisvideo?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly kms?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly lakeformation?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly lambda?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly lexmodels?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly licensemanager?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly lightsail?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly macie?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly macie2?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly managedblockchain?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly marketplacecatalog?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly mediaconnect?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly mediaconvert?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly medialive?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly mediapackage?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly mediastore?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly mediastoredata?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly mq?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly mwaa?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly neptune?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly networkfirewall?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly networkmanager?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly opsworks?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly organizations?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly outposts?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly personalize?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly pinpoint?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly pricing?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly qldb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly quicksight?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ram?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly rds?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly redshift?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly resourcegroups?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly resourcegroupstaggingapi?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly route53?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly route53Domains?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly route53Resolver?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly s3?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly s3Control?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly s3Outposts?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly sagemaker?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly sdb?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly secretsmanager?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly securityhub?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly serverlessrepo?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly servicecatalog?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly servicediscovery?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly servicequotas?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ses?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly shield?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly signer?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly sns?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly sqs?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ssm?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly ssoadmin?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly stepfunctions?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly storagegateway?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly sts?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly swf?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly synthetics?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly timestreamwrite?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly transfer?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly waf?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly wafregional?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly wafv2?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly worklink?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly workmail?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly workspaces?: string;
    /**
     * Use this to override the default service endpoint URL.
     *
     * @stability stable
     */
    readonly xray?: string;
}
/**
 * @stability stable
 */
export interface AwsProviderIgnoreTags {
    /**
     * Resource tag key prefixes to ignore across all resources.
     *
     * @stability stable
     */
    readonly keyPrefixes?: string[];
    /**
     * Resource tag keys to ignore across all resources.
     *
     * @stability stable
     */
    readonly keys?: string[];
}
/**
 * @stability stable
 */
export declare class AwsProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AwsProviderConfig);
    private _accessKey?;
    /**
     * @stability stable
     */
    get accessKey(): string | undefined;
    /**
     * @stability stable
     */
    set accessKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetAccessKey(): void;
    /**
     * @stability stable
     */
    get accessKeyInput(): string | undefined;
    private _allowedAccountIds?;
    /**
     * @stability stable
     */
    get allowedAccountIds(): string[] | undefined;
    /**
     * @stability stable
     */
    set allowedAccountIds(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedAccountIds(): void;
    /**
     * @stability stable
     */
    get allowedAccountIdsInput(): string[] | undefined;
    private _forbiddenAccountIds?;
    /**
     * @stability stable
     */
    get forbiddenAccountIds(): string[] | undefined;
    /**
     * @stability stable
     */
    set forbiddenAccountIds(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetForbiddenAccountIds(): void;
    /**
     * @stability stable
     */
    get forbiddenAccountIdsInput(): string[] | undefined;
    private _insecure?;
    /**
     * @stability stable
     */
    get insecure(): boolean | undefined;
    /**
     * @stability stable
     */
    set insecure(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetInsecure(): void;
    /**
     * @stability stable
     */
    get insecureInput(): boolean | undefined;
    private _maxRetries?;
    /**
     * @stability stable
     */
    get maxRetries(): number | undefined;
    /**
     * @stability stable
     */
    set maxRetries(value: number | undefined);
    /**
     * @stability stable
     */
    resetMaxRetries(): void;
    /**
     * @stability stable
     */
    get maxRetriesInput(): number | undefined;
    private _profile?;
    /**
     * @stability stable
     */
    get profile(): string | undefined;
    /**
     * @stability stable
     */
    set profile(value: string | undefined);
    /**
     * @stability stable
     */
    resetProfile(): void;
    /**
     * @stability stable
     */
    get profileInput(): string | undefined;
    private _region;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    get regionInput(): string;
    private _s3ForcePathStyle?;
    /**
     * @stability stable
     */
    get s3ForcePathStyle(): boolean | undefined;
    /**
     * @stability stable
     */
    set s3ForcePathStyle(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetS3ForcePathStyle(): void;
    /**
     * @stability stable
     */
    get s3ForcePathStyleInput(): boolean | undefined;
    private _secretKey?;
    /**
     * @stability stable
     */
    get secretKey(): string | undefined;
    /**
     * @stability stable
     */
    set secretKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetSecretKey(): void;
    /**
     * @stability stable
     */
    get secretKeyInput(): string | undefined;
    private _sharedCredentialsFile?;
    /**
     * @stability stable
     */
    get sharedCredentialsFile(): string | undefined;
    /**
     * @stability stable
     */
    set sharedCredentialsFile(value: string | undefined);
    /**
     * @stability stable
     */
    resetSharedCredentialsFile(): void;
    /**
     * @stability stable
     */
    get sharedCredentialsFileInput(): string | undefined;
    private _skipCredentialsValidation?;
    /**
     * @stability stable
     */
    get skipCredentialsValidation(): boolean | undefined;
    /**
     * @stability stable
     */
    set skipCredentialsValidation(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetSkipCredentialsValidation(): void;
    /**
     * @stability stable
     */
    get skipCredentialsValidationInput(): boolean | undefined;
    private _skipGetEc2Platforms?;
    /**
     * @stability stable
     */
    get skipGetEc2Platforms(): boolean | undefined;
    /**
     * @stability stable
     */
    set skipGetEc2Platforms(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetSkipGetEc2Platforms(): void;
    /**
     * @stability stable
     */
    get skipGetEc2PlatformsInput(): boolean | undefined;
    private _skipMetadataApiCheck?;
    /**
     * @stability stable
     */
    get skipMetadataApiCheck(): boolean | undefined;
    /**
     * @stability stable
     */
    set skipMetadataApiCheck(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetSkipMetadataApiCheck(): void;
    /**
     * @stability stable
     */
    get skipMetadataApiCheckInput(): boolean | undefined;
    private _skipRegionValidation?;
    /**
     * @stability stable
     */
    get skipRegionValidation(): boolean | undefined;
    /**
     * @stability stable
     */
    set skipRegionValidation(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetSkipRegionValidation(): void;
    /**
     * @stability stable
     */
    get skipRegionValidationInput(): boolean | undefined;
    private _skipRequestingAccountId?;
    /**
     * @stability stable
     */
    get skipRequestingAccountId(): boolean | undefined;
    /**
     * @stability stable
     */
    set skipRequestingAccountId(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetSkipRequestingAccountId(): void;
    /**
     * @stability stable
     */
    get skipRequestingAccountIdInput(): boolean | undefined;
    private _token?;
    /**
     * @stability stable
     */
    get token(): string | undefined;
    /**
     * @stability stable
     */
    set token(value: string | undefined);
    /**
     * @stability stable
     */
    resetToken(): void;
    /**
     * @stability stable
     */
    get tokenInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    private _assumeRole?;
    /**
     * @stability stable
     */
    get assumeRole(): AwsProviderAssumeRole[] | undefined;
    /**
     * @stability stable
     */
    set assumeRole(value: AwsProviderAssumeRole[] | undefined);
    /**
     * @stability stable
     */
    resetAssumeRole(): void;
    /**
     * @stability stable
     */
    get assumeRoleInput(): AwsProviderAssumeRole[] | undefined;
    private _defaultTags?;
    /**
     * @stability stable
     */
    get defaultTags(): AwsProviderDefaultTags[] | undefined;
    /**
     * @stability stable
     */
    set defaultTags(value: AwsProviderDefaultTags[] | undefined);
    /**
     * @stability stable
     */
    resetDefaultTags(): void;
    /**
     * @stability stable
     */
    get defaultTagsInput(): AwsProviderDefaultTags[] | undefined;
    private _endpoints?;
    /**
     * @stability stable
     */
    get endpoints(): AwsProviderEndpoints[] | undefined;
    /**
     * @stability stable
     */
    set endpoints(value: AwsProviderEndpoints[] | undefined);
    /**
     * @stability stable
     */
    resetEndpoints(): void;
    /**
     * @stability stable
     */
    get endpointsInput(): AwsProviderEndpoints[] | undefined;
    private _ignoreTags?;
    /**
     * @stability stable
     */
    get ignoreTags(): AwsProviderIgnoreTags[] | undefined;
    /**
     * @stability stable
     */
    set ignoreTags(value: AwsProviderIgnoreTags[] | undefined);
    /**
     * @stability stable
     */
    resetIgnoreTags(): void;
    /**
     * @stability stable
     */
    get ignoreTagsInput(): AwsProviderIgnoreTags[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
