import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CodepipelineConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * artifact_store block.
     *
     * @stability stable
     */
    readonly artifactStore: CodepipelineArtifactStore[];
    /**
     * stage block.
     *
     * @stability stable
     */
    readonly stage: CodepipelineStage[];
}
/**
 * @stability stable
 */
export interface CodepipelineArtifactStoreEncryptionKey {
    /**
     * @stability stable
     */
    readonly id: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface CodepipelineArtifactStore {
    /**
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly region?: string;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * encryption_key block.
     *
     * @stability stable
     */
    readonly encryptionKey?: CodepipelineArtifactStoreEncryptionKey[];
}
/**
 * @stability stable
 */
export interface CodepipelineStageAction {
    /**
     * @stability stable
     */
    readonly category: string;
    /**
     * @stability stable
     */
    readonly configuration?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly inputArtifacts?: string[];
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly namespace?: string;
    /**
     * @stability stable
     */
    readonly outputArtifacts?: string[];
    /**
     * @stability stable
     */
    readonly owner: string;
    /**
     * @stability stable
     */
    readonly provider: string;
    /**
     * @stability stable
     */
    readonly region?: string;
    /**
     * @stability stable
     */
    readonly roleArn?: string;
    /**
     * @stability stable
     */
    readonly runOrder?: number;
    /**
     * @stability stable
     */
    readonly version: string;
}
/**
 * @stability stable
 */
export interface CodepipelineStage {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * action block.
     *
     * @stability stable
     */
    readonly action: CodepipelineStageAction[];
}
/**
 * @stability stable
 */
export declare class Codepipeline extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CodepipelineConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _roleArn;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _artifactStore;
    /**
     * @stability stable
     */
    get artifactStore(): CodepipelineArtifactStore[];
    /**
     * @stability stable
     */
    set artifactStore(value: CodepipelineArtifactStore[]);
    /**
     * @stability stable
     */
    get artifactStoreInput(): CodepipelineArtifactStore[];
    private _stage;
    /**
     * @stability stable
     */
    get stage(): CodepipelineStage[];
    /**
     * @stability stable
     */
    set stage(value: CodepipelineStage[]);
    /**
     * @stability stable
     */
    get stageInput(): CodepipelineStage[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
