import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DaxClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly availabilityZones?: string[];
    /**
     * @stability stable
     */
    readonly clusterName: string;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly iamRoleArn: string;
    /**
     * @stability stable
     */
    readonly maintenanceWindow?: string;
    /**
     * @stability stable
     */
    readonly nodeType: string;
    /**
     * @stability stable
     */
    readonly notificationTopicArn?: string;
    /**
     * @stability stable
     */
    readonly parameterGroupName?: string;
    /**
     * @stability stable
     */
    readonly replicationFactor: number;
    /**
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * @stability stable
     */
    readonly subnetGroupName?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * server_side_encryption block.
     *
     * @stability stable
     */
    readonly serverSideEncryption?: DaxClusterServerSideEncryption[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DaxClusterTimeouts;
}
/**
 * @stability stable
 */
export declare class DaxClusterNodes extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get address(): string;
    /**
     * @stability stable
     */
    get availabilityZone(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get port(): number;
}
/**
 * @stability stable
 */
export interface DaxClusterServerSideEncryption {
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
}
/**
 * @stability stable
 */
export interface DaxClusterTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class DaxCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DaxClusterConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _availabilityZones?;
    /**
     * @stability stable
     */
    get availabilityZones(): string[];
    /**
     * @stability stable
     */
    set availabilityZones(value: string[]);
    /**
     * @stability stable
     */
    resetAvailabilityZones(): void;
    /**
     * @stability stable
     */
    get availabilityZonesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get clusterAddress(): string;
    private _clusterName;
    /**
     * @stability stable
     */
    get clusterName(): string;
    /**
     * @stability stable
     */
    set clusterName(value: string);
    /**
     * @stability stable
     */
    get clusterNameInput(): string;
    /**
     * @stability stable
     */
    get configurationEndpoint(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _iamRoleArn;
    /**
     * @stability stable
     */
    get iamRoleArn(): string;
    /**
     * @stability stable
     */
    set iamRoleArn(value: string);
    /**
     * @stability stable
     */
    get iamRoleArnInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _maintenanceWindow?;
    /**
     * @stability stable
     */
    get maintenanceWindow(): string;
    /**
     * @stability stable
     */
    set maintenanceWindow(value: string);
    /**
     * @stability stable
     */
    resetMaintenanceWindow(): void;
    /**
     * @stability stable
     */
    get maintenanceWindowInput(): string | undefined;
    private _nodeType;
    /**
     * @stability stable
     */
    get nodeType(): string;
    /**
     * @stability stable
     */
    set nodeType(value: string);
    /**
     * @stability stable
     */
    get nodeTypeInput(): string;
    /**
     * @stability stable
     */
    nodes(index: string): DaxClusterNodes;
    private _notificationTopicArn?;
    /**
     * @stability stable
     */
    get notificationTopicArn(): string;
    /**
     * @stability stable
     */
    set notificationTopicArn(value: string);
    /**
     * @stability stable
     */
    resetNotificationTopicArn(): void;
    /**
     * @stability stable
     */
    get notificationTopicArnInput(): string | undefined;
    private _parameterGroupName?;
    /**
     * @stability stable
     */
    get parameterGroupName(): string;
    /**
     * @stability stable
     */
    set parameterGroupName(value: string);
    /**
     * @stability stable
     */
    resetParameterGroupName(): void;
    /**
     * @stability stable
     */
    get parameterGroupNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get port(): number;
    private _replicationFactor;
    /**
     * @stability stable
     */
    get replicationFactor(): number;
    /**
     * @stability stable
     */
    set replicationFactor(value: number);
    /**
     * @stability stable
     */
    get replicationFactorInput(): number;
    private _securityGroupIds?;
    /**
     * @stability stable
     */
    get securityGroupIds(): string[];
    /**
     * @stability stable
     */
    set securityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get securityGroupIdsInput(): string[] | undefined;
    private _subnetGroupName?;
    /**
     * @stability stable
     */
    get subnetGroupName(): string;
    /**
     * @stability stable
     */
    set subnetGroupName(value: string);
    /**
     * @stability stable
     */
    resetSubnetGroupName(): void;
    /**
     * @stability stable
     */
    get subnetGroupNameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _serverSideEncryption?;
    /**
     * @stability stable
     */
    get serverSideEncryption(): DaxClusterServerSideEncryption[];
    /**
     * @stability stable
     */
    set serverSideEncryption(value: DaxClusterServerSideEncryption[]);
    /**
     * @stability stable
     */
    resetServerSideEncryption(): void;
    /**
     * @stability stable
     */
    get serverSideEncryptionInput(): DaxClusterServerSideEncryption[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DaxClusterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DaxClusterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DaxClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
