import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DmsEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly certificateArn?: string;
    /**
     * @stability stable
     */
    readonly databaseName?: string;
    /**
     * @stability stable
     */
    readonly endpointId: string;
    /**
     * @stability stable
     */
    readonly endpointType: string;
    /**
     * @stability stable
     */
    readonly engineName: string;
    /**
     * @stability stable
     */
    readonly extraConnectionAttributes?: string;
    /**
     * @stability stable
     */
    readonly kmsKeyArn?: string;
    /**
     * @stability stable
     */
    readonly password?: string;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly serverName?: string;
    /**
     * @stability stable
     */
    readonly serviceAccessRole?: string;
    /**
     * @stability stable
     */
    readonly sslMode?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly username?: string;
    /**
     * elasticsearch_settings block.
     *
     * @stability stable
     */
    readonly elasticsearchSettings?: DmsEndpointElasticsearchSettings[];
    /**
     * kafka_settings block.
     *
     * @stability stable
     */
    readonly kafkaSettings?: DmsEndpointKafkaSettings[];
    /**
     * kinesis_settings block.
     *
     * @stability stable
     */
    readonly kinesisSettings?: DmsEndpointKinesisSettings[];
    /**
     * mongodb_settings block.
     *
     * @stability stable
     */
    readonly mongodbSettings?: DmsEndpointMongodbSettings[];
    /**
     * s3_settings block.
     *
     * @stability stable
     */
    readonly s3Settings?: DmsEndpointS3Settings[];
}
/**
 * @stability stable
 */
export interface DmsEndpointElasticsearchSettings {
    /**
     * @stability stable
     */
    readonly endpointUri: string;
    /**
     * @stability stable
     */
    readonly errorRetryDuration?: number;
    /**
     * @stability stable
     */
    readonly fullLoadErrorPercentage?: number;
    /**
     * @stability stable
     */
    readonly serviceAccessRoleArn: string;
}
/**
 * @stability stable
 */
export interface DmsEndpointKafkaSettings {
    /**
     * @stability stable
     */
    readonly broker: string;
    /**
     * @stability stable
     */
    readonly topic?: string;
}
/**
 * @stability stable
 */
export interface DmsEndpointKinesisSettings {
    /**
     * @stability stable
     */
    readonly messageFormat?: string;
    /**
     * @stability stable
     */
    readonly serviceAccessRoleArn?: string;
    /**
     * @stability stable
     */
    readonly streamArn?: string;
}
/**
 * @stability stable
 */
export interface DmsEndpointMongodbSettings {
    /**
     * @stability stable
     */
    readonly authMechanism?: string;
    /**
     * @stability stable
     */
    readonly authSource?: string;
    /**
     * @stability stable
     */
    readonly authType?: string;
    /**
     * @stability stable
     */
    readonly docsToInvestigate?: string;
    /**
     * @stability stable
     */
    readonly extractDocId?: string;
    /**
     * @stability stable
     */
    readonly nestingLevel?: string;
}
/**
 * @stability stable
 */
export interface DmsEndpointS3Settings {
    /**
     * @stability stable
     */
    readonly bucketFolder?: string;
    /**
     * @stability stable
     */
    readonly bucketName?: string;
    /**
     * @stability stable
     */
    readonly compressionType?: string;
    /**
     * @stability stable
     */
    readonly csvDelimiter?: string;
    /**
     * @stability stable
     */
    readonly csvRowDelimiter?: string;
    /**
     * @stability stable
     */
    readonly datePartitionEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly externalTableDefinition?: string;
    /**
     * @stability stable
     */
    readonly serviceAccessRoleArn?: string;
}
/**
 * @stability stable
 */
export declare class DmsEndpoint extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DmsEndpointConfig);
    private _certificateArn?;
    /**
     * @stability stable
     */
    get certificateArn(): string;
    /**
     * @stability stable
     */
    set certificateArn(value: string);
    /**
     * @stability stable
     */
    resetCertificateArn(): void;
    /**
     * @stability stable
     */
    get certificateArnInput(): string | undefined;
    private _databaseName?;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    resetDatabaseName(): void;
    /**
     * @stability stable
     */
    get databaseNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get endpointArn(): string;
    private _endpointId;
    /**
     * @stability stable
     */
    get endpointId(): string;
    /**
     * @stability stable
     */
    set endpointId(value: string);
    /**
     * @stability stable
     */
    get endpointIdInput(): string;
    private _endpointType;
    /**
     * @stability stable
     */
    get endpointType(): string;
    /**
     * @stability stable
     */
    set endpointType(value: string);
    /**
     * @stability stable
     */
    get endpointTypeInput(): string;
    private _engineName;
    /**
     * @stability stable
     */
    get engineName(): string;
    /**
     * @stability stable
     */
    set engineName(value: string);
    /**
     * @stability stable
     */
    get engineNameInput(): string;
    private _extraConnectionAttributes?;
    /**
     * @stability stable
     */
    get extraConnectionAttributes(): string;
    /**
     * @stability stable
     */
    set extraConnectionAttributes(value: string);
    /**
     * @stability stable
     */
    resetExtraConnectionAttributes(): void;
    /**
     * @stability stable
     */
    get extraConnectionAttributesInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kmsKeyArn?;
    /**
     * @stability stable
     */
    get kmsKeyArn(): string;
    /**
     * @stability stable
     */
    set kmsKeyArn(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyArn(): void;
    /**
     * @stability stable
     */
    get kmsKeyArnInput(): string | undefined;
    private _password?;
    /**
     * @stability stable
     */
    get password(): string;
    /**
     * @stability stable
     */
    set password(value: string);
    /**
     * @stability stable
     */
    resetPassword(): void;
    /**
     * @stability stable
     */
    get passwordInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
    private _serverName?;
    /**
     * @stability stable
     */
    get serverName(): string;
    /**
     * @stability stable
     */
    set serverName(value: string);
    /**
     * @stability stable
     */
    resetServerName(): void;
    /**
     * @stability stable
     */
    get serverNameInput(): string | undefined;
    private _serviceAccessRole?;
    /**
     * @stability stable
     */
    get serviceAccessRole(): string;
    /**
     * @stability stable
     */
    set serviceAccessRole(value: string);
    /**
     * @stability stable
     */
    resetServiceAccessRole(): void;
    /**
     * @stability stable
     */
    get serviceAccessRoleInput(): string | undefined;
    private _sslMode?;
    /**
     * @stability stable
     */
    get sslMode(): string;
    /**
     * @stability stable
     */
    set sslMode(value: string);
    /**
     * @stability stable
     */
    resetSslMode(): void;
    /**
     * @stability stable
     */
    get sslModeInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _username?;
    /**
     * @stability stable
     */
    get username(): string;
    /**
     * @stability stable
     */
    set username(value: string);
    /**
     * @stability stable
     */
    resetUsername(): void;
    /**
     * @stability stable
     */
    get usernameInput(): string | undefined;
    private _elasticsearchSettings?;
    /**
     * @stability stable
     */
    get elasticsearchSettings(): DmsEndpointElasticsearchSettings[];
    /**
     * @stability stable
     */
    set elasticsearchSettings(value: DmsEndpointElasticsearchSettings[]);
    /**
     * @stability stable
     */
    resetElasticsearchSettings(): void;
    /**
     * @stability stable
     */
    get elasticsearchSettingsInput(): DmsEndpointElasticsearchSettings[] | undefined;
    private _kafkaSettings?;
    /**
     * @stability stable
     */
    get kafkaSettings(): DmsEndpointKafkaSettings[];
    /**
     * @stability stable
     */
    set kafkaSettings(value: DmsEndpointKafkaSettings[]);
    /**
     * @stability stable
     */
    resetKafkaSettings(): void;
    /**
     * @stability stable
     */
    get kafkaSettingsInput(): DmsEndpointKafkaSettings[] | undefined;
    private _kinesisSettings?;
    /**
     * @stability stable
     */
    get kinesisSettings(): DmsEndpointKinesisSettings[];
    /**
     * @stability stable
     */
    set kinesisSettings(value: DmsEndpointKinesisSettings[]);
    /**
     * @stability stable
     */
    resetKinesisSettings(): void;
    /**
     * @stability stable
     */
    get kinesisSettingsInput(): DmsEndpointKinesisSettings[] | undefined;
    private _mongodbSettings?;
    /**
     * @stability stable
     */
    get mongodbSettings(): DmsEndpointMongodbSettings[];
    /**
     * @stability stable
     */
    set mongodbSettings(value: DmsEndpointMongodbSettings[]);
    /**
     * @stability stable
     */
    resetMongodbSettings(): void;
    /**
     * @stability stable
     */
    get mongodbSettingsInput(): DmsEndpointMongodbSettings[] | undefined;
    private _s3Settings?;
    /**
     * @stability stable
     */
    get s3Settings(): DmsEndpointS3Settings[];
    /**
     * @stability stable
     */
    set s3Settings(value: DmsEndpointS3Settings[]);
    /**
     * @stability stable
     */
    resetS3Settings(): void;
    /**
     * @stability stable
     */
    get s3SettingsInput(): DmsEndpointS3Settings[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
