import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DynamodbTableConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly billingMode?: string;
    /**
     * @stability stable
     */
    readonly hashKey: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly rangeKey?: string;
    /**
     * @stability stable
     */
    readonly readCapacity?: number;
    /**
     * @stability stable
     */
    readonly streamEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly streamViewType?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly writeCapacity?: number;
    /**
     * attribute block.
     *
     * @stability stable
     */
    readonly attribute: DynamodbTableAttribute[];
    /**
     * global_secondary_index block.
     *
     * @stability stable
     */
    readonly globalSecondaryIndex?: DynamodbTableGlobalSecondaryIndex[];
    /**
     * local_secondary_index block.
     *
     * @stability stable
     */
    readonly localSecondaryIndex?: DynamodbTableLocalSecondaryIndex[];
    /**
     * point_in_time_recovery block.
     *
     * @stability stable
     */
    readonly pointInTimeRecovery?: DynamodbTablePointInTimeRecovery[];
    /**
     * replica block.
     *
     * @stability stable
     */
    readonly replica?: DynamodbTableReplica[];
    /**
     * server_side_encryption block.
     *
     * @stability stable
     */
    readonly serverSideEncryption?: DynamodbTableServerSideEncryption[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DynamodbTableTimeouts;
    /**
     * ttl block.
     *
     * @stability stable
     */
    readonly ttl?: DynamodbTableTtl[];
}
/**
 * @stability stable
 */
export interface DynamodbTableAttribute {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface DynamodbTableGlobalSecondaryIndex {
    /**
     * @stability stable
     */
    readonly hashKey: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly nonKeyAttributes?: string[];
    /**
     * @stability stable
     */
    readonly projectionType: string;
    /**
     * @stability stable
     */
    readonly rangeKey?: string;
    /**
     * @stability stable
     */
    readonly readCapacity?: number;
    /**
     * @stability stable
     */
    readonly writeCapacity?: number;
}
/**
 * @stability stable
 */
export interface DynamodbTableLocalSecondaryIndex {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly nonKeyAttributes?: string[];
    /**
     * @stability stable
     */
    readonly projectionType: string;
    /**
     * @stability stable
     */
    readonly rangeKey: string;
}
/**
 * @stability stable
 */
export interface DynamodbTablePointInTimeRecovery {
    /**
     * @stability stable
     */
    readonly enabled: boolean;
}
/**
 * @stability stable
 */
export interface DynamodbTableReplica {
    /**
     * @stability stable
     */
    readonly regionName: string;
}
/**
 * @stability stable
 */
export interface DynamodbTableServerSideEncryption {
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * @stability stable
     */
    readonly kmsKeyArn?: string;
}
/**
 * @stability stable
 */
export interface DynamodbTableTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface DynamodbTableTtl {
    /**
     * @stability stable
     */
    readonly attributeName: string;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
}
/**
 * @stability stable
 */
export declare class DynamodbTable extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DynamodbTableConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _billingMode?;
    /**
     * @stability stable
     */
    get billingMode(): string;
    /**
     * @stability stable
     */
    set billingMode(value: string);
    /**
     * @stability stable
     */
    resetBillingMode(): void;
    /**
     * @stability stable
     */
    get billingModeInput(): string | undefined;
    private _hashKey;
    /**
     * @stability stable
     */
    get hashKey(): string;
    /**
     * @stability stable
     */
    set hashKey(value: string);
    /**
     * @stability stable
     */
    get hashKeyInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _rangeKey?;
    /**
     * @stability stable
     */
    get rangeKey(): string;
    /**
     * @stability stable
     */
    set rangeKey(value: string);
    /**
     * @stability stable
     */
    resetRangeKey(): void;
    /**
     * @stability stable
     */
    get rangeKeyInput(): string | undefined;
    private _readCapacity?;
    /**
     * @stability stable
     */
    get readCapacity(): number;
    /**
     * @stability stable
     */
    set readCapacity(value: number);
    /**
     * @stability stable
     */
    resetReadCapacity(): void;
    /**
     * @stability stable
     */
    get readCapacityInput(): number | undefined;
    /**
     * @stability stable
     */
    get streamArn(): string;
    private _streamEnabled?;
    /**
     * @stability stable
     */
    get streamEnabled(): boolean;
    /**
     * @stability stable
     */
    set streamEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetStreamEnabled(): void;
    /**
     * @stability stable
     */
    get streamEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get streamLabel(): string;
    private _streamViewType?;
    /**
     * @stability stable
     */
    get streamViewType(): string;
    /**
     * @stability stable
     */
    set streamViewType(value: string);
    /**
     * @stability stable
     */
    resetStreamViewType(): void;
    /**
     * @stability stable
     */
    get streamViewTypeInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _writeCapacity?;
    /**
     * @stability stable
     */
    get writeCapacity(): number;
    /**
     * @stability stable
     */
    set writeCapacity(value: number);
    /**
     * @stability stable
     */
    resetWriteCapacity(): void;
    /**
     * @stability stable
     */
    get writeCapacityInput(): number | undefined;
    private _attribute;
    /**
     * @stability stable
     */
    get attribute(): DynamodbTableAttribute[];
    /**
     * @stability stable
     */
    set attribute(value: DynamodbTableAttribute[]);
    /**
     * @stability stable
     */
    get attributeInput(): DynamodbTableAttribute[];
    private _globalSecondaryIndex?;
    /**
     * @stability stable
     */
    get globalSecondaryIndex(): DynamodbTableGlobalSecondaryIndex[];
    /**
     * @stability stable
     */
    set globalSecondaryIndex(value: DynamodbTableGlobalSecondaryIndex[]);
    /**
     * @stability stable
     */
    resetGlobalSecondaryIndex(): void;
    /**
     * @stability stable
     */
    get globalSecondaryIndexInput(): DynamodbTableGlobalSecondaryIndex[] | undefined;
    private _localSecondaryIndex?;
    /**
     * @stability stable
     */
    get localSecondaryIndex(): DynamodbTableLocalSecondaryIndex[];
    /**
     * @stability stable
     */
    set localSecondaryIndex(value: DynamodbTableLocalSecondaryIndex[]);
    /**
     * @stability stable
     */
    resetLocalSecondaryIndex(): void;
    /**
     * @stability stable
     */
    get localSecondaryIndexInput(): DynamodbTableLocalSecondaryIndex[] | undefined;
    private _pointInTimeRecovery?;
    /**
     * @stability stable
     */
    get pointInTimeRecovery(): DynamodbTablePointInTimeRecovery[];
    /**
     * @stability stable
     */
    set pointInTimeRecovery(value: DynamodbTablePointInTimeRecovery[]);
    /**
     * @stability stable
     */
    resetPointInTimeRecovery(): void;
    /**
     * @stability stable
     */
    get pointInTimeRecoveryInput(): DynamodbTablePointInTimeRecovery[] | undefined;
    private _replica?;
    /**
     * @stability stable
     */
    get replica(): DynamodbTableReplica[];
    /**
     * @stability stable
     */
    set replica(value: DynamodbTableReplica[]);
    /**
     * @stability stable
     */
    resetReplica(): void;
    /**
     * @stability stable
     */
    get replicaInput(): DynamodbTableReplica[] | undefined;
    private _serverSideEncryption?;
    /**
     * @stability stable
     */
    get serverSideEncryption(): DynamodbTableServerSideEncryption[];
    /**
     * @stability stable
     */
    set serverSideEncryption(value: DynamodbTableServerSideEncryption[]);
    /**
     * @stability stable
     */
    resetServerSideEncryption(): void;
    /**
     * @stability stable
     */
    get serverSideEncryptionInput(): DynamodbTableServerSideEncryption[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DynamodbTableTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DynamodbTableTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DynamodbTableTimeouts | undefined;
    private _ttl?;
    /**
     * @stability stable
     */
    get ttl(): DynamodbTableTtl[];
    /**
     * @stability stable
     */
    set ttl(value: DynamodbTableTtl[]);
    /**
     * @stability stable
     */
    resetTtl(): void;
    /**
     * @stability stable
     */
    get ttlInput(): DynamodbTableTtl[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
