import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EcrRepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly imageTagMutability?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * encryption_configuration block.
     *
     * @stability stable
     */
    readonly encryptionConfiguration?: EcrRepositoryEncryptionConfiguration[];
    /**
     * image_scanning_configuration block.
     *
     * @stability stable
     */
    readonly imageScanningConfiguration?: EcrRepositoryImageScanningConfiguration[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: EcrRepositoryTimeouts;
}
/**
 * @stability stable
 */
export interface EcrRepositoryEncryptionConfiguration {
    /**
     * @stability stable
     */
    readonly encryptionType?: string;
    /**
     * @stability stable
     */
    readonly kmsKey?: string;
}
/**
 * @stability stable
 */
export interface EcrRepositoryImageScanningConfiguration {
    /**
     * @stability stable
     */
    readonly scanOnPush: boolean;
}
/**
 * @stability stable
 */
export interface EcrRepositoryTimeouts {
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class EcrRepository extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcrRepositoryConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _imageTagMutability?;
    /**
     * @stability stable
     */
    get imageTagMutability(): string;
    /**
     * @stability stable
     */
    set imageTagMutability(value: string);
    /**
     * @stability stable
     */
    resetImageTagMutability(): void;
    /**
     * @stability stable
     */
    get imageTagMutabilityInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get registryId(): string;
    /**
     * @stability stable
     */
    get repositoryUrl(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _encryptionConfiguration?;
    /**
     * @stability stable
     */
    get encryptionConfiguration(): EcrRepositoryEncryptionConfiguration[];
    /**
     * @stability stable
     */
    set encryptionConfiguration(value: EcrRepositoryEncryptionConfiguration[]);
    /**
     * @stability stable
     */
    resetEncryptionConfiguration(): void;
    /**
     * @stability stable
     */
    get encryptionConfigurationInput(): EcrRepositoryEncryptionConfiguration[] | undefined;
    private _imageScanningConfiguration?;
    /**
     * @stability stable
     */
    get imageScanningConfiguration(): EcrRepositoryImageScanningConfiguration[];
    /**
     * @stability stable
     */
    set imageScanningConfiguration(value: EcrRepositoryImageScanningConfiguration[]);
    /**
     * @stability stable
     */
    resetImageScanningConfiguration(): void;
    /**
     * @stability stable
     */
    get imageScanningConfigurationInput(): EcrRepositoryImageScanningConfiguration[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): EcrRepositoryTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: EcrRepositoryTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EcrRepositoryTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
