import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EcsServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly cluster?: string;
    /**
     * @stability stable
     */
    readonly deploymentMaximumPercent?: number;
    /**
     * @stability stable
     */
    readonly deploymentMinimumHealthyPercent?: number;
    /**
     * @stability stable
     */
    readonly desiredCount?: number;
    /**
     * @stability stable
     */
    readonly enableEcsManagedTags?: boolean;
    /**
     * @stability stable
     */
    readonly forceNewDeployment?: boolean;
    /**
     * @stability stable
     */
    readonly healthCheckGracePeriodSeconds?: number;
    /**
     * @stability stable
     */
    readonly iamRole?: string;
    /**
     * @stability stable
     */
    readonly launchType?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly platformVersion?: string;
    /**
     * @stability stable
     */
    readonly propagateTags?: string;
    /**
     * @stability stable
     */
    readonly schedulingStrategy?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly taskDefinition?: string;
    /**
     * @stability stable
     */
    readonly waitForSteadyState?: boolean;
    /**
     * capacity_provider_strategy block.
     *
     * @stability stable
     */
    readonly capacityProviderStrategy?: EcsServiceCapacityProviderStrategy[];
    /**
     * deployment_controller block.
     *
     * @stability stable
     */
    readonly deploymentController?: EcsServiceDeploymentController[];
    /**
     * load_balancer block.
     *
     * @stability stable
     */
    readonly loadBalancer?: EcsServiceLoadBalancer[];
    /**
     * network_configuration block.
     *
     * @stability stable
     */
    readonly networkConfiguration?: EcsServiceNetworkConfiguration[];
    /**
     * ordered_placement_strategy block.
     *
     * @stability stable
     */
    readonly orderedPlacementStrategy?: EcsServiceOrderedPlacementStrategy[];
    /**
     * placement_constraints block.
     *
     * @stability stable
     */
    readonly placementConstraints?: EcsServicePlacementConstraints[];
    /**
     * service_registries block.
     *
     * @stability stable
     */
    readonly serviceRegistries?: EcsServiceServiceRegistries[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: EcsServiceTimeouts;
}
/**
 * @stability stable
 */
export interface EcsServiceCapacityProviderStrategy {
    /**
     * @stability stable
     */
    readonly base?: number;
    /**
     * @stability stable
     */
    readonly capacityProvider: string;
    /**
     * @stability stable
     */
    readonly weight?: number;
}
/**
 * @stability stable
 */
export interface EcsServiceDeploymentController {
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface EcsServiceLoadBalancer {
    /**
     * @stability stable
     */
    readonly containerName: string;
    /**
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * @stability stable
     */
    readonly elbName?: string;
    /**
     * @stability stable
     */
    readonly targetGroupArn?: string;
}
/**
 * @stability stable
 */
export interface EcsServiceNetworkConfiguration {
    /**
     * @stability stable
     */
    readonly assignPublicIp?: boolean;
    /**
     * @stability stable
     */
    readonly securityGroups?: string[];
    /**
     * @stability stable
     */
    readonly subnets: string[];
}
/**
 * @stability stable
 */
export interface EcsServiceOrderedPlacementStrategy {
    /**
     * @stability stable
     */
    readonly field?: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface EcsServicePlacementConstraints {
    /**
     * @stability stable
     */
    readonly expression?: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface EcsServiceServiceRegistries {
    /**
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * @stability stable
     */
    readonly containerPort?: number;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly registryArn: string;
}
/**
 * @stability stable
 */
export interface EcsServiceTimeouts {
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class EcsService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcsServiceConfig);
    private _cluster?;
    /**
     * @stability stable
     */
    get cluster(): string;
    /**
     * @stability stable
     */
    set cluster(value: string);
    /**
     * @stability stable
     */
    resetCluster(): void;
    /**
     * @stability stable
     */
    get clusterInput(): string | undefined;
    private _deploymentMaximumPercent?;
    /**
     * @stability stable
     */
    get deploymentMaximumPercent(): number;
    /**
     * @stability stable
     */
    set deploymentMaximumPercent(value: number);
    /**
     * @stability stable
     */
    resetDeploymentMaximumPercent(): void;
    /**
     * @stability stable
     */
    get deploymentMaximumPercentInput(): number | undefined;
    private _deploymentMinimumHealthyPercent?;
    /**
     * @stability stable
     */
    get deploymentMinimumHealthyPercent(): number;
    /**
     * @stability stable
     */
    set deploymentMinimumHealthyPercent(value: number);
    /**
     * @stability stable
     */
    resetDeploymentMinimumHealthyPercent(): void;
    /**
     * @stability stable
     */
    get deploymentMinimumHealthyPercentInput(): number | undefined;
    private _desiredCount?;
    /**
     * @stability stable
     */
    get desiredCount(): number;
    /**
     * @stability stable
     */
    set desiredCount(value: number);
    /**
     * @stability stable
     */
    resetDesiredCount(): void;
    /**
     * @stability stable
     */
    get desiredCountInput(): number | undefined;
    private _enableEcsManagedTags?;
    /**
     * @stability stable
     */
    get enableEcsManagedTags(): boolean;
    /**
     * @stability stable
     */
    set enableEcsManagedTags(value: boolean);
    /**
     * @stability stable
     */
    resetEnableEcsManagedTags(): void;
    /**
     * @stability stable
     */
    get enableEcsManagedTagsInput(): boolean | undefined;
    private _forceNewDeployment?;
    /**
     * @stability stable
     */
    get forceNewDeployment(): boolean;
    /**
     * @stability stable
     */
    set forceNewDeployment(value: boolean);
    /**
     * @stability stable
     */
    resetForceNewDeployment(): void;
    /**
     * @stability stable
     */
    get forceNewDeploymentInput(): boolean | undefined;
    private _healthCheckGracePeriodSeconds?;
    /**
     * @stability stable
     */
    get healthCheckGracePeriodSeconds(): number;
    /**
     * @stability stable
     */
    set healthCheckGracePeriodSeconds(value: number);
    /**
     * @stability stable
     */
    resetHealthCheckGracePeriodSeconds(): void;
    /**
     * @stability stable
     */
    get healthCheckGracePeriodSecondsInput(): number | undefined;
    private _iamRole?;
    /**
     * @stability stable
     */
    get iamRole(): string;
    /**
     * @stability stable
     */
    set iamRole(value: string);
    /**
     * @stability stable
     */
    resetIamRole(): void;
    /**
     * @stability stable
     */
    get iamRoleInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _launchType?;
    /**
     * @stability stable
     */
    get launchType(): string;
    /**
     * @stability stable
     */
    set launchType(value: string);
    /**
     * @stability stable
     */
    resetLaunchType(): void;
    /**
     * @stability stable
     */
    get launchTypeInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _platformVersion?;
    /**
     * @stability stable
     */
    get platformVersion(): string;
    /**
     * @stability stable
     */
    set platformVersion(value: string);
    /**
     * @stability stable
     */
    resetPlatformVersion(): void;
    /**
     * @stability stable
     */
    get platformVersionInput(): string | undefined;
    private _propagateTags?;
    /**
     * @stability stable
     */
    get propagateTags(): string;
    /**
     * @stability stable
     */
    set propagateTags(value: string);
    /**
     * @stability stable
     */
    resetPropagateTags(): void;
    /**
     * @stability stable
     */
    get propagateTagsInput(): string | undefined;
    private _schedulingStrategy?;
    /**
     * @stability stable
     */
    get schedulingStrategy(): string;
    /**
     * @stability stable
     */
    set schedulingStrategy(value: string);
    /**
     * @stability stable
     */
    resetSchedulingStrategy(): void;
    /**
     * @stability stable
     */
    get schedulingStrategyInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _taskDefinition?;
    /**
     * @stability stable
     */
    get taskDefinition(): string;
    /**
     * @stability stable
     */
    set taskDefinition(value: string);
    /**
     * @stability stable
     */
    resetTaskDefinition(): void;
    /**
     * @stability stable
     */
    get taskDefinitionInput(): string | undefined;
    private _waitForSteadyState?;
    /**
     * @stability stable
     */
    get waitForSteadyState(): boolean;
    /**
     * @stability stable
     */
    set waitForSteadyState(value: boolean);
    /**
     * @stability stable
     */
    resetWaitForSteadyState(): void;
    /**
     * @stability stable
     */
    get waitForSteadyStateInput(): boolean | undefined;
    private _capacityProviderStrategy?;
    /**
     * @stability stable
     */
    get capacityProviderStrategy(): EcsServiceCapacityProviderStrategy[];
    /**
     * @stability stable
     */
    set capacityProviderStrategy(value: EcsServiceCapacityProviderStrategy[]);
    /**
     * @stability stable
     */
    resetCapacityProviderStrategy(): void;
    /**
     * @stability stable
     */
    get capacityProviderStrategyInput(): EcsServiceCapacityProviderStrategy[] | undefined;
    private _deploymentController?;
    /**
     * @stability stable
     */
    get deploymentController(): EcsServiceDeploymentController[];
    /**
     * @stability stable
     */
    set deploymentController(value: EcsServiceDeploymentController[]);
    /**
     * @stability stable
     */
    resetDeploymentController(): void;
    /**
     * @stability stable
     */
    get deploymentControllerInput(): EcsServiceDeploymentController[] | undefined;
    private _loadBalancer?;
    /**
     * @stability stable
     */
    get loadBalancer(): EcsServiceLoadBalancer[];
    /**
     * @stability stable
     */
    set loadBalancer(value: EcsServiceLoadBalancer[]);
    /**
     * @stability stable
     */
    resetLoadBalancer(): void;
    /**
     * @stability stable
     */
    get loadBalancerInput(): EcsServiceLoadBalancer[] | undefined;
    private _networkConfiguration?;
    /**
     * @stability stable
     */
    get networkConfiguration(): EcsServiceNetworkConfiguration[];
    /**
     * @stability stable
     */
    set networkConfiguration(value: EcsServiceNetworkConfiguration[]);
    /**
     * @stability stable
     */
    resetNetworkConfiguration(): void;
    /**
     * @stability stable
     */
    get networkConfigurationInput(): EcsServiceNetworkConfiguration[] | undefined;
    private _orderedPlacementStrategy?;
    /**
     * @stability stable
     */
    get orderedPlacementStrategy(): EcsServiceOrderedPlacementStrategy[];
    /**
     * @stability stable
     */
    set orderedPlacementStrategy(value: EcsServiceOrderedPlacementStrategy[]);
    /**
     * @stability stable
     */
    resetOrderedPlacementStrategy(): void;
    /**
     * @stability stable
     */
    get orderedPlacementStrategyInput(): EcsServiceOrderedPlacementStrategy[] | undefined;
    private _placementConstraints?;
    /**
     * @stability stable
     */
    get placementConstraints(): EcsServicePlacementConstraints[];
    /**
     * @stability stable
     */
    set placementConstraints(value: EcsServicePlacementConstraints[]);
    /**
     * @stability stable
     */
    resetPlacementConstraints(): void;
    /**
     * @stability stable
     */
    get placementConstraintsInput(): EcsServicePlacementConstraints[] | undefined;
    private _serviceRegistries?;
    /**
     * @stability stable
     */
    get serviceRegistries(): EcsServiceServiceRegistries[];
    /**
     * @stability stable
     */
    set serviceRegistries(value: EcsServiceServiceRegistries[]);
    /**
     * @stability stable
     */
    resetServiceRegistries(): void;
    /**
     * @stability stable
     */
    get serviceRegistriesInput(): EcsServiceServiceRegistries[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): EcsServiceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: EcsServiceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EcsServiceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
