import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EcsTaskDefinitionConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly containerDefinitions: string;
    /**
     * @stability stable
     */
    readonly cpu?: string;
    /**
     * @stability stable
     */
    readonly executionRoleArn?: string;
    /**
     * @stability stable
     */
    readonly family: string;
    /**
     * @stability stable
     */
    readonly ipcMode?: string;
    /**
     * @stability stable
     */
    readonly memory?: string;
    /**
     * @stability stable
     */
    readonly networkMode?: string;
    /**
     * @stability stable
     */
    readonly pidMode?: string;
    /**
     * @stability stable
     */
    readonly requiresCompatibilities?: string[];
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly taskRoleArn?: string;
    /**
     * inference_accelerator block.
     *
     * @stability stable
     */
    readonly inferenceAccelerator?: EcsTaskDefinitionInferenceAccelerator[];
    /**
     * placement_constraints block.
     *
     * @stability stable
     */
    readonly placementConstraints?: EcsTaskDefinitionPlacementConstraints[];
    /**
     * proxy_configuration block.
     *
     * @stability stable
     */
    readonly proxyConfiguration?: EcsTaskDefinitionProxyConfiguration[];
    /**
     * volume block.
     *
     * @stability stable
     */
    readonly volume?: EcsTaskDefinitionVolume[];
}
/**
 * @stability stable
 */
export interface EcsTaskDefinitionInferenceAccelerator {
    /**
     * @stability stable
     */
    readonly deviceName: string;
    /**
     * @stability stable
     */
    readonly deviceType: string;
}
/**
 * @stability stable
 */
export interface EcsTaskDefinitionPlacementConstraints {
    /**
     * @stability stable
     */
    readonly expression?: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface EcsTaskDefinitionProxyConfiguration {
    /**
     * @stability stable
     */
    readonly containerName: string;
    /**
     * @stability stable
     */
    readonly properties?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface EcsTaskDefinitionVolumeDockerVolumeConfiguration {
    /**
     * @stability stable
     */
    readonly autoprovision?: boolean;
    /**
     * @stability stable
     */
    readonly driver?: string;
    /**
     * @stability stable
     */
    readonly driverOpts?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly scope?: string;
}
/**
 * @stability stable
 */
export interface EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig {
    /**
     * @stability stable
     */
    readonly accessPointId?: string;
    /**
     * @stability stable
     */
    readonly iam?: string;
}
/**
 * @stability stable
 */
export interface EcsTaskDefinitionVolumeEfsVolumeConfiguration {
    /**
     * @stability stable
     */
    readonly fileSystemId: string;
    /**
     * @stability stable
     */
    readonly rootDirectory?: string;
    /**
     * @stability stable
     */
    readonly transitEncryption?: string;
    /**
     * @stability stable
     */
    readonly transitEncryptionPort?: number;
    /**
     * authorization_config block.
     *
     * @stability stable
     */
    readonly authorizationConfig?: EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig[];
}
/**
 * @stability stable
 */
export interface EcsTaskDefinitionVolume {
    /**
     * @stability stable
     */
    readonly hostPath?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * docker_volume_configuration block.
     *
     * @stability stable
     */
    readonly dockerVolumeConfiguration?: EcsTaskDefinitionVolumeDockerVolumeConfiguration[];
    /**
     * efs_volume_configuration block.
     *
     * @stability stable
     */
    readonly efsVolumeConfiguration?: EcsTaskDefinitionVolumeEfsVolumeConfiguration[];
}
/**
 * @stability stable
 */
export declare class EcsTaskDefinition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcsTaskDefinitionConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _containerDefinitions;
    /**
     * @stability stable
     */
    get containerDefinitions(): string;
    /**
     * @stability stable
     */
    set containerDefinitions(value: string);
    /**
     * @stability stable
     */
    get containerDefinitionsInput(): string;
    private _cpu?;
    /**
     * @stability stable
     */
    get cpu(): string;
    /**
     * @stability stable
     */
    set cpu(value: string);
    /**
     * @stability stable
     */
    resetCpu(): void;
    /**
     * @stability stable
     */
    get cpuInput(): string | undefined;
    private _executionRoleArn?;
    /**
     * @stability stable
     */
    get executionRoleArn(): string;
    /**
     * @stability stable
     */
    set executionRoleArn(value: string);
    /**
     * @stability stable
     */
    resetExecutionRoleArn(): void;
    /**
     * @stability stable
     */
    get executionRoleArnInput(): string | undefined;
    private _family;
    /**
     * @stability stable
     */
    get family(): string;
    /**
     * @stability stable
     */
    set family(value: string);
    /**
     * @stability stable
     */
    get familyInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipcMode?;
    /**
     * @stability stable
     */
    get ipcMode(): string;
    /**
     * @stability stable
     */
    set ipcMode(value: string);
    /**
     * @stability stable
     */
    resetIpcMode(): void;
    /**
     * @stability stable
     */
    get ipcModeInput(): string | undefined;
    private _memory?;
    /**
     * @stability stable
     */
    get memory(): string;
    /**
     * @stability stable
     */
    set memory(value: string);
    /**
     * @stability stable
     */
    resetMemory(): void;
    /**
     * @stability stable
     */
    get memoryInput(): string | undefined;
    private _networkMode?;
    /**
     * @stability stable
     */
    get networkMode(): string;
    /**
     * @stability stable
     */
    set networkMode(value: string);
    /**
     * @stability stable
     */
    resetNetworkMode(): void;
    /**
     * @stability stable
     */
    get networkModeInput(): string | undefined;
    private _pidMode?;
    /**
     * @stability stable
     */
    get pidMode(): string;
    /**
     * @stability stable
     */
    set pidMode(value: string);
    /**
     * @stability stable
     */
    resetPidMode(): void;
    /**
     * @stability stable
     */
    get pidModeInput(): string | undefined;
    private _requiresCompatibilities?;
    /**
     * @stability stable
     */
    get requiresCompatibilities(): string[];
    /**
     * @stability stable
     */
    set requiresCompatibilities(value: string[]);
    /**
     * @stability stable
     */
    resetRequiresCompatibilities(): void;
    /**
     * @stability stable
     */
    get requiresCompatibilitiesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get revision(): number;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _taskRoleArn?;
    /**
     * @stability stable
     */
    get taskRoleArn(): string;
    /**
     * @stability stable
     */
    set taskRoleArn(value: string);
    /**
     * @stability stable
     */
    resetTaskRoleArn(): void;
    /**
     * @stability stable
     */
    get taskRoleArnInput(): string | undefined;
    private _inferenceAccelerator?;
    /**
     * @stability stable
     */
    get inferenceAccelerator(): EcsTaskDefinitionInferenceAccelerator[];
    /**
     * @stability stable
     */
    set inferenceAccelerator(value: EcsTaskDefinitionInferenceAccelerator[]);
    /**
     * @stability stable
     */
    resetInferenceAccelerator(): void;
    /**
     * @stability stable
     */
    get inferenceAcceleratorInput(): EcsTaskDefinitionInferenceAccelerator[] | undefined;
    private _placementConstraints?;
    /**
     * @stability stable
     */
    get placementConstraints(): EcsTaskDefinitionPlacementConstraints[];
    /**
     * @stability stable
     */
    set placementConstraints(value: EcsTaskDefinitionPlacementConstraints[]);
    /**
     * @stability stable
     */
    resetPlacementConstraints(): void;
    /**
     * @stability stable
     */
    get placementConstraintsInput(): EcsTaskDefinitionPlacementConstraints[] | undefined;
    private _proxyConfiguration?;
    /**
     * @stability stable
     */
    get proxyConfiguration(): EcsTaskDefinitionProxyConfiguration[];
    /**
     * @stability stable
     */
    set proxyConfiguration(value: EcsTaskDefinitionProxyConfiguration[]);
    /**
     * @stability stable
     */
    resetProxyConfiguration(): void;
    /**
     * @stability stable
     */
    get proxyConfigurationInput(): EcsTaskDefinitionProxyConfiguration[] | undefined;
    private _volume?;
    /**
     * @stability stable
     */
    get volume(): EcsTaskDefinitionVolume[];
    /**
     * @stability stable
     */
    set volume(value: EcsTaskDefinitionVolume[]);
    /**
     * @stability stable
     */
    resetVolume(): void;
    /**
     * @stability stable
     */
    get volumeInput(): EcsTaskDefinitionVolume[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
