import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EksClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly enabledClusterLogTypes?: string[];
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly version?: string;
    /**
     * encryption_config block.
     *
     * @stability stable
     */
    readonly encryptionConfig?: EksClusterEncryptionConfig[];
    /**
     * kubernetes_network_config block.
     *
     * @stability stable
     */
    readonly kubernetesNetworkConfig?: EksClusterKubernetesNetworkConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: EksClusterTimeouts;
    /**
     * vpc_config block.
     *
     * @stability stable
     */
    readonly vpcConfig: EksClusterVpcConfig[];
}
/**
 * @stability stable
 */
export declare class EksClusterCertificateAuthority extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get data(): string;
}
/**
 * @stability stable
 */
export declare class EksClusterIdentityOidc extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get issuer(): string;
}
/**
 * @stability stable
 */
export declare class EksClusterIdentity extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get oidc(): any;
}
/**
 * @stability stable
 */
export interface EksClusterEncryptionConfigProvider {
    /**
     * @stability stable
     */
    readonly keyArn: string;
}
/**
 * @stability stable
 */
export interface EksClusterEncryptionConfig {
    /**
     * @stability stable
     */
    readonly resources: string[];
    /**
     * provider block.
     *
     * @stability stable
     */
    readonly provider: EksClusterEncryptionConfigProvider[];
}
/**
 * @stability stable
 */
export interface EksClusterKubernetesNetworkConfig {
    /**
     * @stability stable
     */
    readonly serviceIpv4Cidr?: string;
}
/**
 * @stability stable
 */
export interface EksClusterTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface EksClusterVpcConfig {
    /**
     * @stability stable
     */
    readonly endpointPrivateAccess?: boolean;
    /**
     * @stability stable
     */
    readonly endpointPublicAccess?: boolean;
    /**
     * @stability stable
     */
    readonly publicAccessCidrs?: string[];
    /**
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * @stability stable
     */
    readonly subnetIds: string[];
}
/**
 * @stability stable
 */
export declare class EksCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EksClusterConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    certificateAuthority(index: string): EksClusterCertificateAuthority;
    /**
     * @stability stable
     */
    get createdAt(): string;
    private _enabledClusterLogTypes?;
    /**
     * @stability stable
     */
    get enabledClusterLogTypes(): string[];
    /**
     * @stability stable
     */
    set enabledClusterLogTypes(value: string[]);
    /**
     * @stability stable
     */
    resetEnabledClusterLogTypes(): void;
    /**
     * @stability stable
     */
    get enabledClusterLogTypesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    identity(index: string): EksClusterIdentity;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get platformVersion(): string;
    private _roleArn;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _version?;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    resetVersion(): void;
    /**
     * @stability stable
     */
    get versionInput(): string | undefined;
    private _encryptionConfig?;
    /**
     * @stability stable
     */
    get encryptionConfig(): EksClusterEncryptionConfig[];
    /**
     * @stability stable
     */
    set encryptionConfig(value: EksClusterEncryptionConfig[]);
    /**
     * @stability stable
     */
    resetEncryptionConfig(): void;
    /**
     * @stability stable
     */
    get encryptionConfigInput(): EksClusterEncryptionConfig[] | undefined;
    private _kubernetesNetworkConfig?;
    /**
     * @stability stable
     */
    get kubernetesNetworkConfig(): EksClusterKubernetesNetworkConfig[];
    /**
     * @stability stable
     */
    set kubernetesNetworkConfig(value: EksClusterKubernetesNetworkConfig[]);
    /**
     * @stability stable
     */
    resetKubernetesNetworkConfig(): void;
    /**
     * @stability stable
     */
    get kubernetesNetworkConfigInput(): EksClusterKubernetesNetworkConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): EksClusterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: EksClusterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EksClusterTimeouts | undefined;
    private _vpcConfig;
    /**
     * @stability stable
     */
    get vpcConfig(): EksClusterVpcConfig[];
    /**
     * @stability stable
     */
    set vpcConfig(value: EksClusterVpcConfig[]);
    /**
     * @stability stable
     */
    get vpcConfigInput(): EksClusterVpcConfig[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
