import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ElasticsearchDomainConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly accessPolicies?: string;
    /**
     * @stability stable
     */
    readonly advancedOptions?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly domainName: string;
    /**
     * @stability stable
     */
    readonly elasticsearchVersion?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * advanced_security_options block.
     *
     * @stability stable
     */
    readonly advancedSecurityOptions?: ElasticsearchDomainAdvancedSecurityOptions[];
    /**
     * cluster_config block.
     *
     * @stability stable
     */
    readonly clusterConfig?: ElasticsearchDomainClusterConfig[];
    /**
     * cognito_options block.
     *
     * @stability stable
     */
    readonly cognitoOptions?: ElasticsearchDomainCognitoOptions[];
    /**
     * domain_endpoint_options block.
     *
     * @stability stable
     */
    readonly domainEndpointOptions?: ElasticsearchDomainDomainEndpointOptions[];
    /**
     * ebs_options block.
     *
     * @stability stable
     */
    readonly ebsOptions?: ElasticsearchDomainEbsOptions[];
    /**
     * encrypt_at_rest block.
     *
     * @stability stable
     */
    readonly encryptAtRest?: ElasticsearchDomainEncryptAtRest[];
    /**
     * log_publishing_options block.
     *
     * @stability stable
     */
    readonly logPublishingOptions?: ElasticsearchDomainLogPublishingOptions[];
    /**
     * node_to_node_encryption block.
     *
     * @stability stable
     */
    readonly nodeToNodeEncryption?: ElasticsearchDomainNodeToNodeEncryption[];
    /**
     * snapshot_options block.
     *
     * @stability stable
     */
    readonly snapshotOptions?: ElasticsearchDomainSnapshotOptions[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ElasticsearchDomainTimeouts;
    /**
     * vpc_options block.
     *
     * @stability stable
     */
    readonly vpcOptions?: ElasticsearchDomainVpcOptions[];
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions {
    /**
     * @stability stable
     */
    readonly masterUserArn?: string;
    /**
     * @stability stable
     */
    readonly masterUserName?: string;
    /**
     * @stability stable
     */
    readonly masterUserPassword?: string;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainAdvancedSecurityOptions {
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * @stability stable
     */
    readonly internalUserDatabaseEnabled?: boolean;
    /**
     * master_user_options block.
     *
     * @stability stable
     */
    readonly masterUserOptions?: ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions[];
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainClusterConfigZoneAwarenessConfig {
    /**
     * @stability stable
     */
    readonly availabilityZoneCount?: number;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainClusterConfig {
    /**
     * @stability stable
     */
    readonly dedicatedMasterCount?: number;
    /**
     * @stability stable
     */
    readonly dedicatedMasterEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly dedicatedMasterType?: string;
    /**
     * @stability stable
     */
    readonly instanceCount?: number;
    /**
     * @stability stable
     */
    readonly instanceType?: string;
    /**
     * @stability stable
     */
    readonly warmCount?: number;
    /**
     * @stability stable
     */
    readonly warmEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly warmType?: string;
    /**
     * @stability stable
     */
    readonly zoneAwarenessEnabled?: boolean;
    /**
     * zone_awareness_config block.
     *
     * @stability stable
     */
    readonly zoneAwarenessConfig?: ElasticsearchDomainClusterConfigZoneAwarenessConfig[];
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainCognitoOptions {
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly identityPoolId: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * @stability stable
     */
    readonly userPoolId: string;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainDomainEndpointOptions {
    /**
     * @stability stable
     */
    readonly enforceHttps: boolean;
    /**
     * @stability stable
     */
    readonly tlsSecurityPolicy?: string;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainEbsOptions {
    /**
     * @stability stable
     */
    readonly ebsEnabled: boolean;
    /**
     * @stability stable
     */
    readonly iops?: number;
    /**
     * @stability stable
     */
    readonly volumeSize?: number;
    /**
     * @stability stable
     */
    readonly volumeType?: string;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainEncryptAtRest {
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * @stability stable
     */
    readonly kmsKeyId?: string;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainLogPublishingOptions {
    /**
     * @stability stable
     */
    readonly cloudwatchLogGroupArn: string;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly logType: string;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainNodeToNodeEncryption {
    /**
     * @stability stable
     */
    readonly enabled: boolean;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainSnapshotOptions {
    /**
     * @stability stable
     */
    readonly automatedSnapshotStartHour: number;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainTimeouts {
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainVpcOptions {
    /**
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * @stability stable
     */
    readonly subnetIds?: string[];
}
/**
 * @stability stable
 */
export declare class ElasticsearchDomain extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ElasticsearchDomainConfig);
    private _accessPolicies?;
    /**
     * @stability stable
     */
    get accessPolicies(): string;
    /**
     * @stability stable
     */
    set accessPolicies(value: string);
    /**
     * @stability stable
     */
    resetAccessPolicies(): void;
    /**
     * @stability stable
     */
    get accessPoliciesInput(): string | undefined;
    private _advancedOptions?;
    /**
     * @stability stable
     */
    get advancedOptions(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set advancedOptions(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetAdvancedOptions(): void;
    /**
     * @stability stable
     */
    get advancedOptionsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get domainId(): string;
    private _domainName;
    /**
     * @stability stable
     */
    get domainName(): string;
    /**
     * @stability stable
     */
    set domainName(value: string);
    /**
     * @stability stable
     */
    get domainNameInput(): string;
    private _elasticsearchVersion?;
    /**
     * @stability stable
     */
    get elasticsearchVersion(): string;
    /**
     * @stability stable
     */
    set elasticsearchVersion(value: string);
    /**
     * @stability stable
     */
    resetElasticsearchVersion(): void;
    /**
     * @stability stable
     */
    get elasticsearchVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get kibanaEndpoint(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _advancedSecurityOptions?;
    /**
     * @stability stable
     */
    get advancedSecurityOptions(): ElasticsearchDomainAdvancedSecurityOptions[];
    /**
     * @stability stable
     */
    set advancedSecurityOptions(value: ElasticsearchDomainAdvancedSecurityOptions[]);
    /**
     * @stability stable
     */
    resetAdvancedSecurityOptions(): void;
    /**
     * @stability stable
     */
    get advancedSecurityOptionsInput(): ElasticsearchDomainAdvancedSecurityOptions[] | undefined;
    private _clusterConfig?;
    /**
     * @stability stable
     */
    get clusterConfig(): ElasticsearchDomainClusterConfig[];
    /**
     * @stability stable
     */
    set clusterConfig(value: ElasticsearchDomainClusterConfig[]);
    /**
     * @stability stable
     */
    resetClusterConfig(): void;
    /**
     * @stability stable
     */
    get clusterConfigInput(): ElasticsearchDomainClusterConfig[] | undefined;
    private _cognitoOptions?;
    /**
     * @stability stable
     */
    get cognitoOptions(): ElasticsearchDomainCognitoOptions[];
    /**
     * @stability stable
     */
    set cognitoOptions(value: ElasticsearchDomainCognitoOptions[]);
    /**
     * @stability stable
     */
    resetCognitoOptions(): void;
    /**
     * @stability stable
     */
    get cognitoOptionsInput(): ElasticsearchDomainCognitoOptions[] | undefined;
    private _domainEndpointOptions?;
    /**
     * @stability stable
     */
    get domainEndpointOptions(): ElasticsearchDomainDomainEndpointOptions[];
    /**
     * @stability stable
     */
    set domainEndpointOptions(value: ElasticsearchDomainDomainEndpointOptions[]);
    /**
     * @stability stable
     */
    resetDomainEndpointOptions(): void;
    /**
     * @stability stable
     */
    get domainEndpointOptionsInput(): ElasticsearchDomainDomainEndpointOptions[] | undefined;
    private _ebsOptions?;
    /**
     * @stability stable
     */
    get ebsOptions(): ElasticsearchDomainEbsOptions[];
    /**
     * @stability stable
     */
    set ebsOptions(value: ElasticsearchDomainEbsOptions[]);
    /**
     * @stability stable
     */
    resetEbsOptions(): void;
    /**
     * @stability stable
     */
    get ebsOptionsInput(): ElasticsearchDomainEbsOptions[] | undefined;
    private _encryptAtRest?;
    /**
     * @stability stable
     */
    get encryptAtRest(): ElasticsearchDomainEncryptAtRest[];
    /**
     * @stability stable
     */
    set encryptAtRest(value: ElasticsearchDomainEncryptAtRest[]);
    /**
     * @stability stable
     */
    resetEncryptAtRest(): void;
    /**
     * @stability stable
     */
    get encryptAtRestInput(): ElasticsearchDomainEncryptAtRest[] | undefined;
    private _logPublishingOptions?;
    /**
     * @stability stable
     */
    get logPublishingOptions(): ElasticsearchDomainLogPublishingOptions[];
    /**
     * @stability stable
     */
    set logPublishingOptions(value: ElasticsearchDomainLogPublishingOptions[]);
    /**
     * @stability stable
     */
    resetLogPublishingOptions(): void;
    /**
     * @stability stable
     */
    get logPublishingOptionsInput(): ElasticsearchDomainLogPublishingOptions[] | undefined;
    private _nodeToNodeEncryption?;
    /**
     * @stability stable
     */
    get nodeToNodeEncryption(): ElasticsearchDomainNodeToNodeEncryption[];
    /**
     * @stability stable
     */
    set nodeToNodeEncryption(value: ElasticsearchDomainNodeToNodeEncryption[]);
    /**
     * @stability stable
     */
    resetNodeToNodeEncryption(): void;
    /**
     * @stability stable
     */
    get nodeToNodeEncryptionInput(): ElasticsearchDomainNodeToNodeEncryption[] | undefined;
    private _snapshotOptions?;
    /**
     * @stability stable
     */
    get snapshotOptions(): ElasticsearchDomainSnapshotOptions[];
    /**
     * @stability stable
     */
    set snapshotOptions(value: ElasticsearchDomainSnapshotOptions[]);
    /**
     * @stability stable
     */
    resetSnapshotOptions(): void;
    /**
     * @stability stable
     */
    get snapshotOptionsInput(): ElasticsearchDomainSnapshotOptions[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ElasticsearchDomainTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ElasticsearchDomainTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ElasticsearchDomainTimeouts | undefined;
    private _vpcOptions?;
    /**
     * @stability stable
     */
    get vpcOptions(): ElasticsearchDomainVpcOptions[];
    /**
     * @stability stable
     */
    set vpcOptions(value: ElasticsearchDomainVpcOptions[]);
    /**
     * @stability stable
     */
    resetVpcOptions(): void;
    /**
     * @stability stable
     */
    get vpcOptionsInput(): ElasticsearchDomainVpcOptions[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
