import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GameliftFleetConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly buildId: string;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly ec2InstanceType: string;
    /**
     * @stability stable
     */
    readonly fleetType?: string;
    /**
     * @stability stable
     */
    readonly instanceRoleArn?: string;
    /**
     * @stability stable
     */
    readonly metricGroups?: string[];
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly newGameSessionProtectionPolicy?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * ec2_inbound_permission block.
     *
     * @stability stable
     */
    readonly ec2InboundPermission?: GameliftFleetEc2InboundPermission[];
    /**
     * resource_creation_limit_policy block.
     *
     * @stability stable
     */
    readonly resourceCreationLimitPolicy?: GameliftFleetResourceCreationLimitPolicy[];
    /**
     * runtime_configuration block.
     *
     * @stability stable
     */
    readonly runtimeConfiguration?: GameliftFleetRuntimeConfiguration[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: GameliftFleetTimeouts;
}
/**
 * @stability stable
 */
export interface GameliftFleetEc2InboundPermission {
    /**
     * @stability stable
     */
    readonly fromPort: number;
    /**
     * @stability stable
     */
    readonly ipRange: string;
    /**
     * @stability stable
     */
    readonly protocol: string;
    /**
     * @stability stable
     */
    readonly toPort: number;
}
/**
 * @stability stable
 */
export interface GameliftFleetResourceCreationLimitPolicy {
    /**
     * @stability stable
     */
    readonly newGameSessionsPerCreator?: number;
    /**
     * @stability stable
     */
    readonly policyPeriodInMinutes?: number;
}
/**
 * @stability stable
 */
export interface GameliftFleetRuntimeConfigurationServerProcess {
    /**
     * @stability stable
     */
    readonly concurrentExecutions: number;
    /**
     * @stability stable
     */
    readonly launchPath: string;
    /**
     * @stability stable
     */
    readonly parameters?: string;
}
/**
 * @stability stable
 */
export interface GameliftFleetRuntimeConfiguration {
    /**
     * @stability stable
     */
    readonly gameSessionActivationTimeoutSeconds?: number;
    /**
     * @stability stable
     */
    readonly maxConcurrentGameSessionActivations?: number;
    /**
     * server_process block.
     *
     * @stability stable
     */
    readonly serverProcess?: GameliftFleetRuntimeConfigurationServerProcess[];
}
/**
 * @stability stable
 */
export interface GameliftFleetTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class GameliftFleet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GameliftFleetConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _buildId;
    /**
     * @stability stable
     */
    get buildId(): string;
    /**
     * @stability stable
     */
    set buildId(value: string);
    /**
     * @stability stable
     */
    get buildIdInput(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _ec2InstanceType;
    /**
     * @stability stable
     */
    get ec2InstanceType(): string;
    /**
     * @stability stable
     */
    set ec2InstanceType(value: string);
    /**
     * @stability stable
     */
    get ec2InstanceTypeInput(): string;
    private _fleetType?;
    /**
     * @stability stable
     */
    get fleetType(): string;
    /**
     * @stability stable
     */
    set fleetType(value: string);
    /**
     * @stability stable
     */
    resetFleetType(): void;
    /**
     * @stability stable
     */
    get fleetTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _instanceRoleArn?;
    /**
     * @stability stable
     */
    get instanceRoleArn(): string;
    /**
     * @stability stable
     */
    set instanceRoleArn(value: string);
    /**
     * @stability stable
     */
    resetInstanceRoleArn(): void;
    /**
     * @stability stable
     */
    get instanceRoleArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get logPaths(): string[];
    private _metricGroups?;
    /**
     * @stability stable
     */
    get metricGroups(): string[];
    /**
     * @stability stable
     */
    set metricGroups(value: string[]);
    /**
     * @stability stable
     */
    resetMetricGroups(): void;
    /**
     * @stability stable
     */
    get metricGroupsInput(): string[] | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _newGameSessionProtectionPolicy?;
    /**
     * @stability stable
     */
    get newGameSessionProtectionPolicy(): string;
    /**
     * @stability stable
     */
    set newGameSessionProtectionPolicy(value: string);
    /**
     * @stability stable
     */
    resetNewGameSessionProtectionPolicy(): void;
    /**
     * @stability stable
     */
    get newGameSessionProtectionPolicyInput(): string | undefined;
    /**
     * @stability stable
     */
    get operatingSystem(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _ec2InboundPermission?;
    /**
     * @stability stable
     */
    get ec2InboundPermission(): GameliftFleetEc2InboundPermission[];
    /**
     * @stability stable
     */
    set ec2InboundPermission(value: GameliftFleetEc2InboundPermission[]);
    /**
     * @stability stable
     */
    resetEc2InboundPermission(): void;
    /**
     * @stability stable
     */
    get ec2InboundPermissionInput(): GameliftFleetEc2InboundPermission[] | undefined;
    private _resourceCreationLimitPolicy?;
    /**
     * @stability stable
     */
    get resourceCreationLimitPolicy(): GameliftFleetResourceCreationLimitPolicy[];
    /**
     * @stability stable
     */
    set resourceCreationLimitPolicy(value: GameliftFleetResourceCreationLimitPolicy[]);
    /**
     * @stability stable
     */
    resetResourceCreationLimitPolicy(): void;
    /**
     * @stability stable
     */
    get resourceCreationLimitPolicyInput(): GameliftFleetResourceCreationLimitPolicy[] | undefined;
    private _runtimeConfiguration?;
    /**
     * @stability stable
     */
    get runtimeConfiguration(): GameliftFleetRuntimeConfiguration[];
    /**
     * @stability stable
     */
    set runtimeConfiguration(value: GameliftFleetRuntimeConfiguration[]);
    /**
     * @stability stable
     */
    resetRuntimeConfiguration(): void;
    /**
     * @stability stable
     */
    get runtimeConfigurationInput(): GameliftFleetRuntimeConfiguration[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): GameliftFleetTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: GameliftFleetTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): GameliftFleetTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
