import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GlueCatalogTableConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly catalogId?: string;
    /**
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly owner?: string;
    /**
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly retention?: number;
    /**
     * @stability stable
     */
    readonly tableType?: string;
    /**
     * @stability stable
     */
    readonly viewExpandedText?: string;
    /**
     * @stability stable
     */
    readonly viewOriginalText?: string;
    /**
     * partition_index block.
     *
     * @stability stable
     */
    readonly partitionIndex?: GlueCatalogTablePartitionIndex[];
    /**
     * partition_keys block.
     *
     * @stability stable
     */
    readonly partitionKeys?: GlueCatalogTablePartitionKeys[];
    /**
     * storage_descriptor block.
     *
     * @stability stable
     */
    readonly storageDescriptor?: GlueCatalogTableStorageDescriptor[];
}
/**
 * @stability stable
 */
export interface GlueCatalogTablePartitionIndex {
    /**
     * @stability stable
     */
    readonly indexName: string;
    /**
     * @stability stable
     */
    readonly keys: string[];
}
/**
 * @stability stable
 */
export interface GlueCatalogTablePartitionKeys {
    /**
     * @stability stable
     */
    readonly comment?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface GlueCatalogTableStorageDescriptorColumns {
    /**
     * @stability stable
     */
    readonly comment?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface GlueCatalogTableStorageDescriptorSchemaReferenceSchemaId {
    /**
     * @stability stable
     */
    readonly registryName?: string;
    /**
     * @stability stable
     */
    readonly schemaArn?: string;
    /**
     * @stability stable
     */
    readonly schemaName?: string;
}
/**
 * @stability stable
 */
export interface GlueCatalogTableStorageDescriptorSchemaReference {
    /**
     * @stability stable
     */
    readonly schemaVersionId?: string;
    /**
     * @stability stable
     */
    readonly schemaVersionNumber: number;
    /**
     * schema_id block.
     *
     * @stability stable
     */
    readonly schemaId?: GlueCatalogTableStorageDescriptorSchemaReferenceSchemaId[];
}
/**
 * @stability stable
 */
export interface GlueCatalogTableStorageDescriptorSerDeInfo {
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly serializationLibrary?: string;
}
/**
 * @stability stable
 */
export interface GlueCatalogTableStorageDescriptorSkewedInfo {
    /**
     * @stability stable
     */
    readonly skewedColumnNames?: string[];
    /**
     * @stability stable
     */
    readonly skewedColumnValueLocationMaps?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly skewedColumnValues?: string[];
}
/**
 * @stability stable
 */
export interface GlueCatalogTableStorageDescriptorSortColumns {
    /**
     * @stability stable
     */
    readonly column: string;
    /**
     * @stability stable
     */
    readonly sortOrder: number;
}
/**
 * @stability stable
 */
export interface GlueCatalogTableStorageDescriptor {
    /**
     * @stability stable
     */
    readonly bucketColumns?: string[];
    /**
     * @stability stable
     */
    readonly compressed?: boolean;
    /**
     * @stability stable
     */
    readonly inputFormat?: string;
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly numberOfBuckets?: number;
    /**
     * @stability stable
     */
    readonly outputFormat?: string;
    /**
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly storedAsSubDirectories?: boolean;
    /**
     * columns block.
     *
     * @stability stable
     */
    readonly columns?: GlueCatalogTableStorageDescriptorColumns[];
    /**
     * schema_reference block.
     *
     * @stability stable
     */
    readonly schemaReference?: GlueCatalogTableStorageDescriptorSchemaReference[];
    /**
     * ser_de_info block.
     *
     * @stability stable
     */
    readonly serDeInfo?: GlueCatalogTableStorageDescriptorSerDeInfo[];
    /**
     * skewed_info block.
     *
     * @stability stable
     */
    readonly skewedInfo?: GlueCatalogTableStorageDescriptorSkewedInfo[];
    /**
     * sort_columns block.
     *
     * @stability stable
     */
    readonly sortColumns?: GlueCatalogTableStorageDescriptorSortColumns[];
}
/**
 * @stability stable
 */
export declare class GlueCatalogTable extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GlueCatalogTableConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
    private _databaseName;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    get databaseNameInput(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _owner?;
    /**
     * @stability stable
     */
    get owner(): string;
    /**
     * @stability stable
     */
    set owner(value: string);
    /**
     * @stability stable
     */
    resetOwner(): void;
    /**
     * @stability stable
     */
    get ownerInput(): string | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _retention?;
    /**
     * @stability stable
     */
    get retention(): number;
    /**
     * @stability stable
     */
    set retention(value: number);
    /**
     * @stability stable
     */
    resetRetention(): void;
    /**
     * @stability stable
     */
    get retentionInput(): number | undefined;
    private _tableType?;
    /**
     * @stability stable
     */
    get tableType(): string;
    /**
     * @stability stable
     */
    set tableType(value: string);
    /**
     * @stability stable
     */
    resetTableType(): void;
    /**
     * @stability stable
     */
    get tableTypeInput(): string | undefined;
    private _viewExpandedText?;
    /**
     * @stability stable
     */
    get viewExpandedText(): string;
    /**
     * @stability stable
     */
    set viewExpandedText(value: string);
    /**
     * @stability stable
     */
    resetViewExpandedText(): void;
    /**
     * @stability stable
     */
    get viewExpandedTextInput(): string | undefined;
    private _viewOriginalText?;
    /**
     * @stability stable
     */
    get viewOriginalText(): string;
    /**
     * @stability stable
     */
    set viewOriginalText(value: string);
    /**
     * @stability stable
     */
    resetViewOriginalText(): void;
    /**
     * @stability stable
     */
    get viewOriginalTextInput(): string | undefined;
    private _partitionIndex?;
    /**
     * @stability stable
     */
    get partitionIndex(): GlueCatalogTablePartitionIndex[];
    /**
     * @stability stable
     */
    set partitionIndex(value: GlueCatalogTablePartitionIndex[]);
    /**
     * @stability stable
     */
    resetPartitionIndex(): void;
    /**
     * @stability stable
     */
    get partitionIndexInput(): GlueCatalogTablePartitionIndex[] | undefined;
    private _partitionKeys?;
    /**
     * @stability stable
     */
    get partitionKeys(): GlueCatalogTablePartitionKeys[];
    /**
     * @stability stable
     */
    set partitionKeys(value: GlueCatalogTablePartitionKeys[]);
    /**
     * @stability stable
     */
    resetPartitionKeys(): void;
    /**
     * @stability stable
     */
    get partitionKeysInput(): GlueCatalogTablePartitionKeys[] | undefined;
    private _storageDescriptor?;
    /**
     * @stability stable
     */
    get storageDescriptor(): GlueCatalogTableStorageDescriptor[];
    /**
     * @stability stable
     */
    set storageDescriptor(value: GlueCatalogTableStorageDescriptor[]);
    /**
     * @stability stable
     */
    resetStorageDescriptor(): void;
    /**
     * @stability stable
     */
    get storageDescriptorInput(): GlueCatalogTableStorageDescriptor[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
