import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GlueCrawlerConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly classifiers?: string[];
    /**
     * @stability stable
     */
    readonly configuration?: string;
    /**
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly role: string;
    /**
     * @stability stable
     */
    readonly schedule?: string;
    /**
     * @stability stable
     */
    readonly securityConfiguration?: string;
    /**
     * @stability stable
     */
    readonly tablePrefix?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * catalog_target block.
     *
     * @stability stable
     */
    readonly catalogTarget?: GlueCrawlerCatalogTarget[];
    /**
     * dynamodb_target block.
     *
     * @stability stable
     */
    readonly dynamodbTarget?: GlueCrawlerDynamodbTarget[];
    /**
     * jdbc_target block.
     *
     * @stability stable
     */
    readonly jdbcTarget?: GlueCrawlerJdbcTarget[];
    /**
     * lineage_configuration block.
     *
     * @stability stable
     */
    readonly lineageConfiguration?: GlueCrawlerLineageConfiguration[];
    /**
     * mongodb_target block.
     *
     * @stability stable
     */
    readonly mongodbTarget?: GlueCrawlerMongodbTarget[];
    /**
     * recrawl_policy block.
     *
     * @stability stable
     */
    readonly recrawlPolicy?: GlueCrawlerRecrawlPolicy[];
    /**
     * s3_target block.
     *
     * @stability stable
     */
    readonly s3Target?: GlueCrawlerS3Target[];
    /**
     * schema_change_policy block.
     *
     * @stability stable
     */
    readonly schemaChangePolicy?: GlueCrawlerSchemaChangePolicy[];
}
/**
 * @stability stable
 */
export interface GlueCrawlerCatalogTarget {
    /**
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * @stability stable
     */
    readonly tables: string[];
}
/**
 * @stability stable
 */
export interface GlueCrawlerDynamodbTarget {
    /**
     * @stability stable
     */
    readonly path: string;
    /**
     * @stability stable
     */
    readonly scanAll?: boolean;
    /**
     * @stability stable
     */
    readonly scanRate?: number;
}
/**
 * @stability stable
 */
export interface GlueCrawlerJdbcTarget {
    /**
     * @stability stable
     */
    readonly connectionName: string;
    /**
     * @stability stable
     */
    readonly exclusions?: string[];
    /**
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface GlueCrawlerLineageConfiguration {
    /**
     * @stability stable
     */
    readonly crawlerLineageSettings?: string;
}
/**
 * @stability stable
 */
export interface GlueCrawlerMongodbTarget {
    /**
     * @stability stable
     */
    readonly connectionName: string;
    /**
     * @stability stable
     */
    readonly path: string;
    /**
     * @stability stable
     */
    readonly scanAll?: boolean;
}
/**
 * @stability stable
 */
export interface GlueCrawlerRecrawlPolicy {
    /**
     * @stability stable
     */
    readonly recrawlBehavior?: string;
}
/**
 * @stability stable
 */
export interface GlueCrawlerS3Target {
    /**
     * @stability stable
     */
    readonly connectionName?: string;
    /**
     * @stability stable
     */
    readonly exclusions?: string[];
    /**
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface GlueCrawlerSchemaChangePolicy {
    /**
     * @stability stable
     */
    readonly deleteBehavior?: string;
    /**
     * @stability stable
     */
    readonly updateBehavior?: string;
}
/**
 * @stability stable
 */
export declare class GlueCrawler extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GlueCrawlerConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _classifiers?;
    /**
     * @stability stable
     */
    get classifiers(): string[];
    /**
     * @stability stable
     */
    set classifiers(value: string[]);
    /**
     * @stability stable
     */
    resetClassifiers(): void;
    /**
     * @stability stable
     */
    get classifiersInput(): string[] | undefined;
    private _configuration?;
    /**
     * @stability stable
     */
    get configuration(): string;
    /**
     * @stability stable
     */
    set configuration(value: string);
    /**
     * @stability stable
     */
    resetConfiguration(): void;
    /**
     * @stability stable
     */
    get configurationInput(): string | undefined;
    private _databaseName;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    get databaseNameInput(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _role;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    get roleInput(): string;
    private _schedule?;
    /**
     * @stability stable
     */
    get schedule(): string;
    /**
     * @stability stable
     */
    set schedule(value: string);
    /**
     * @stability stable
     */
    resetSchedule(): void;
    /**
     * @stability stable
     */
    get scheduleInput(): string | undefined;
    private _securityConfiguration?;
    /**
     * @stability stable
     */
    get securityConfiguration(): string;
    /**
     * @stability stable
     */
    set securityConfiguration(value: string);
    /**
     * @stability stable
     */
    resetSecurityConfiguration(): void;
    /**
     * @stability stable
     */
    get securityConfigurationInput(): string | undefined;
    private _tablePrefix?;
    /**
     * @stability stable
     */
    get tablePrefix(): string;
    /**
     * @stability stable
     */
    set tablePrefix(value: string);
    /**
     * @stability stable
     */
    resetTablePrefix(): void;
    /**
     * @stability stable
     */
    get tablePrefixInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _catalogTarget?;
    /**
     * @stability stable
     */
    get catalogTarget(): GlueCrawlerCatalogTarget[];
    /**
     * @stability stable
     */
    set catalogTarget(value: GlueCrawlerCatalogTarget[]);
    /**
     * @stability stable
     */
    resetCatalogTarget(): void;
    /**
     * @stability stable
     */
    get catalogTargetInput(): GlueCrawlerCatalogTarget[] | undefined;
    private _dynamodbTarget?;
    /**
     * @stability stable
     */
    get dynamodbTarget(): GlueCrawlerDynamodbTarget[];
    /**
     * @stability stable
     */
    set dynamodbTarget(value: GlueCrawlerDynamodbTarget[]);
    /**
     * @stability stable
     */
    resetDynamodbTarget(): void;
    /**
     * @stability stable
     */
    get dynamodbTargetInput(): GlueCrawlerDynamodbTarget[] | undefined;
    private _jdbcTarget?;
    /**
     * @stability stable
     */
    get jdbcTarget(): GlueCrawlerJdbcTarget[];
    /**
     * @stability stable
     */
    set jdbcTarget(value: GlueCrawlerJdbcTarget[]);
    /**
     * @stability stable
     */
    resetJdbcTarget(): void;
    /**
     * @stability stable
     */
    get jdbcTargetInput(): GlueCrawlerJdbcTarget[] | undefined;
    private _lineageConfiguration?;
    /**
     * @stability stable
     */
    get lineageConfiguration(): GlueCrawlerLineageConfiguration[];
    /**
     * @stability stable
     */
    set lineageConfiguration(value: GlueCrawlerLineageConfiguration[]);
    /**
     * @stability stable
     */
    resetLineageConfiguration(): void;
    /**
     * @stability stable
     */
    get lineageConfigurationInput(): GlueCrawlerLineageConfiguration[] | undefined;
    private _mongodbTarget?;
    /**
     * @stability stable
     */
    get mongodbTarget(): GlueCrawlerMongodbTarget[];
    /**
     * @stability stable
     */
    set mongodbTarget(value: GlueCrawlerMongodbTarget[]);
    /**
     * @stability stable
     */
    resetMongodbTarget(): void;
    /**
     * @stability stable
     */
    get mongodbTargetInput(): GlueCrawlerMongodbTarget[] | undefined;
    private _recrawlPolicy?;
    /**
     * @stability stable
     */
    get recrawlPolicy(): GlueCrawlerRecrawlPolicy[];
    /**
     * @stability stable
     */
    set recrawlPolicy(value: GlueCrawlerRecrawlPolicy[]);
    /**
     * @stability stable
     */
    resetRecrawlPolicy(): void;
    /**
     * @stability stable
     */
    get recrawlPolicyInput(): GlueCrawlerRecrawlPolicy[] | undefined;
    private _s3Target?;
    /**
     * @stability stable
     */
    get s3Target(): GlueCrawlerS3Target[];
    /**
     * @stability stable
     */
    set s3Target(value: GlueCrawlerS3Target[]);
    /**
     * @stability stable
     */
    resetS3Target(): void;
    /**
     * @stability stable
     */
    get s3TargetInput(): GlueCrawlerS3Target[] | undefined;
    private _schemaChangePolicy?;
    /**
     * @stability stable
     */
    get schemaChangePolicy(): GlueCrawlerSchemaChangePolicy[];
    /**
     * @stability stable
     */
    set schemaChangePolicy(value: GlueCrawlerSchemaChangePolicy[]);
    /**
     * @stability stable
     */
    resetSchemaChangePolicy(): void;
    /**
     * @stability stable
     */
    get schemaChangePolicyInput(): GlueCrawlerSchemaChangePolicy[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
