import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GlueJobConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly connections?: string[];
    /**
     * @stability stable
     */
    readonly defaultArguments?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly glueVersion?: string;
    /**
     * @stability stable
     */
    readonly maxCapacity?: number;
    /**
     * @stability stable
     */
    readonly maxRetries?: number;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly nonOverridableArguments?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly numberOfWorkers?: number;
    /**
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * @stability stable
     */
    readonly securityConfiguration?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * @stability stable
     */
    readonly workerType?: string;
    /**
     * command block.
     *
     * @stability stable
     */
    readonly command: GlueJobCommand[];
    /**
     * execution_property block.
     *
     * @stability stable
     */
    readonly executionProperty?: GlueJobExecutionProperty[];
    /**
     * notification_property block.
     *
     * @stability stable
     */
    readonly notificationProperty?: GlueJobNotificationProperty[];
}
/**
 * @stability stable
 */
export interface GlueJobCommand {
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly pythonVersion?: string;
    /**
     * @stability stable
     */
    readonly scriptLocation: string;
}
/**
 * @stability stable
 */
export interface GlueJobExecutionProperty {
    /**
     * @stability stable
     */
    readonly maxConcurrentRuns?: number;
}
/**
 * @stability stable
 */
export interface GlueJobNotificationProperty {
    /**
     * @stability stable
     */
    readonly notifyDelayAfter?: number;
}
/**
 * @stability stable
 */
export declare class GlueJob extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GlueJobConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _connections?;
    /**
     * @stability stable
     */
    get connections(): string[];
    /**
     * @stability stable
     */
    set connections(value: string[]);
    /**
     * @stability stable
     */
    resetConnections(): void;
    /**
     * @stability stable
     */
    get connectionsInput(): string[] | undefined;
    private _defaultArguments?;
    /**
     * @stability stable
     */
    get defaultArguments(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set defaultArguments(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetDefaultArguments(): void;
    /**
     * @stability stable
     */
    get defaultArgumentsInput(): {
        [key: string]: string;
    } | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _glueVersion?;
    /**
     * @stability stable
     */
    get glueVersion(): string;
    /**
     * @stability stable
     */
    set glueVersion(value: string);
    /**
     * @stability stable
     */
    resetGlueVersion(): void;
    /**
     * @stability stable
     */
    get glueVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _maxCapacity?;
    /**
     * @stability stable
     */
    get maxCapacity(): number;
    /**
     * @stability stable
     */
    set maxCapacity(value: number);
    /**
     * @stability stable
     */
    resetMaxCapacity(): void;
    /**
     * @stability stable
     */
    get maxCapacityInput(): number | undefined;
    private _maxRetries?;
    /**
     * @stability stable
     */
    get maxRetries(): number;
    /**
     * @stability stable
     */
    set maxRetries(value: number);
    /**
     * @stability stable
     */
    resetMaxRetries(): void;
    /**
     * @stability stable
     */
    get maxRetriesInput(): number | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _nonOverridableArguments?;
    /**
     * @stability stable
     */
    get nonOverridableArguments(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set nonOverridableArguments(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetNonOverridableArguments(): void;
    /**
     * @stability stable
     */
    get nonOverridableArgumentsInput(): {
        [key: string]: string;
    } | undefined;
    private _numberOfWorkers?;
    /**
     * @stability stable
     */
    get numberOfWorkers(): number;
    /**
     * @stability stable
     */
    set numberOfWorkers(value: number);
    /**
     * @stability stable
     */
    resetNumberOfWorkers(): void;
    /**
     * @stability stable
     */
    get numberOfWorkersInput(): number | undefined;
    private _roleArn;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string;
    private _securityConfiguration?;
    /**
     * @stability stable
     */
    get securityConfiguration(): string;
    /**
     * @stability stable
     */
    set securityConfiguration(value: string);
    /**
     * @stability stable
     */
    resetSecurityConfiguration(): void;
    /**
     * @stability stable
     */
    get securityConfigurationInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _timeout?;
    /**
     * @stability stable
     */
    get timeout(): number;
    /**
     * @stability stable
     */
    set timeout(value: number);
    /**
     * @stability stable
     */
    resetTimeout(): void;
    /**
     * @stability stable
     */
    get timeoutInput(): number | undefined;
    private _workerType?;
    /**
     * @stability stable
     */
    get workerType(): string;
    /**
     * @stability stable
     */
    set workerType(value: string);
    /**
     * @stability stable
     */
    resetWorkerType(): void;
    /**
     * @stability stable
     */
    get workerTypeInput(): string | undefined;
    private _command;
    /**
     * @stability stable
     */
    get command(): GlueJobCommand[];
    /**
     * @stability stable
     */
    set command(value: GlueJobCommand[]);
    /**
     * @stability stable
     */
    get commandInput(): GlueJobCommand[];
    private _executionProperty?;
    /**
     * @stability stable
     */
    get executionProperty(): GlueJobExecutionProperty[];
    /**
     * @stability stable
     */
    set executionProperty(value: GlueJobExecutionProperty[]);
    /**
     * @stability stable
     */
    resetExecutionProperty(): void;
    /**
     * @stability stable
     */
    get executionPropertyInput(): GlueJobExecutionProperty[] | undefined;
    private _notificationProperty?;
    /**
     * @stability stable
     */
    get notificationProperty(): GlueJobNotificationProperty[];
    /**
     * @stability stable
     */
    set notificationProperty(value: GlueJobNotificationProperty[]);
    /**
     * @stability stable
     */
    resetNotificationProperty(): void;
    /**
     * @stability stable
     */
    get notificationPropertyInput(): GlueJobNotificationProperty[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
