import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly code?: string;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly startApplication?: boolean;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * cloudwatch_logging_options block.
     *
     * @stability stable
     */
    readonly cloudwatchLoggingOptions?: KinesisAnalyticsApplicationCloudwatchLoggingOptions[];
    /**
     * inputs block.
     *
     * @stability stable
     */
    readonly inputs?: KinesisAnalyticsApplicationInputs[];
    /**
     * outputs block.
     *
     * @stability stable
     */
    readonly outputs?: KinesisAnalyticsApplicationOutputs[];
    /**
     * reference_data_sources block.
     *
     * @stability stable
     */
    readonly referenceDataSources?: KinesisAnalyticsApplicationReferenceDataSources[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationCloudwatchLoggingOptions {
    /**
     * @stability stable
     */
    readonly logStreamArn: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsKinesisFirehose {
    /**
     * @stability stable
     */
    readonly resourceArn: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsKinesisStream {
    /**
     * @stability stable
     */
    readonly resourceArn: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsParallelism {
    /**
     * @stability stable
     */
    readonly count?: number;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsProcessingConfigurationLambda {
    /**
     * @stability stable
     */
    readonly resourceArn: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsProcessingConfiguration {
    /**
     * lambda block.
     *
     * @stability stable
     */
    readonly lambda: KinesisAnalyticsApplicationInputsProcessingConfigurationLambda[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsSchemaRecordColumns {
    /**
     * @stability stable
     */
    readonly mapping?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly sqlType: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv {
    /**
     * @stability stable
     */
    readonly recordColumnDelimiter: string;
    /**
     * @stability stable
     */
    readonly recordRowDelimiter: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson {
    /**
     * @stability stable
     */
    readonly recordRowPath: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParameters {
    /**
     * csv block.
     *
     * @stability stable
     */
    readonly csv?: KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv[];
    /**
     * json block.
     *
     * @stability stable
     */
    readonly json?: KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsSchemaRecordFormat {
    /**
     * mapping_parameters block.
     *
     * @stability stable
     */
    readonly mappingParameters?: KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParameters[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsSchema {
    /**
     * @stability stable
     */
    readonly recordEncoding?: string;
    /**
     * record_columns block.
     *
     * @stability stable
     */
    readonly recordColumns: KinesisAnalyticsApplicationInputsSchemaRecordColumns[];
    /**
     * record_format block.
     *
     * @stability stable
     */
    readonly recordFormat: KinesisAnalyticsApplicationInputsSchemaRecordFormat[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputsStartingPositionConfiguration {
    /**
     * @stability stable
     */
    readonly startingPosition?: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationInputs {
    /**
     * @stability stable
     */
    readonly namePrefix: string;
    /**
     * kinesis_firehose block.
     *
     * @stability stable
     */
    readonly kinesisFirehose?: KinesisAnalyticsApplicationInputsKinesisFirehose[];
    /**
     * kinesis_stream block.
     *
     * @stability stable
     */
    readonly kinesisStream?: KinesisAnalyticsApplicationInputsKinesisStream[];
    /**
     * parallelism block.
     *
     * @stability stable
     */
    readonly parallelism?: KinesisAnalyticsApplicationInputsParallelism[];
    /**
     * processing_configuration block.
     *
     * @stability stable
     */
    readonly processingConfiguration?: KinesisAnalyticsApplicationInputsProcessingConfiguration[];
    /**
     * schema block.
     *
     * @stability stable
     */
    readonly schema: KinesisAnalyticsApplicationInputsSchema[];
    /**
     * starting_position_configuration block.
     *
     * @stability stable
     */
    readonly startingPositionConfiguration?: KinesisAnalyticsApplicationInputsStartingPositionConfiguration[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationOutputsKinesisFirehose {
    /**
     * @stability stable
     */
    readonly resourceArn: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationOutputsKinesisStream {
    /**
     * @stability stable
     */
    readonly resourceArn: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationOutputsLambda {
    /**
     * @stability stable
     */
    readonly resourceArn: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationOutputsSchema {
    /**
     * @stability stable
     */
    readonly recordFormatType: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationOutputs {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * kinesis_firehose block.
     *
     * @stability stable
     */
    readonly kinesisFirehose?: KinesisAnalyticsApplicationOutputsKinesisFirehose[];
    /**
     * kinesis_stream block.
     *
     * @stability stable
     */
    readonly kinesisStream?: KinesisAnalyticsApplicationOutputsKinesisStream[];
    /**
     * lambda block.
     *
     * @stability stable
     */
    readonly lambda?: KinesisAnalyticsApplicationOutputsLambda[];
    /**
     * schema block.
     *
     * @stability stable
     */
    readonly schema: KinesisAnalyticsApplicationOutputsSchema[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationReferenceDataSourcesS3 {
    /**
     * @stability stable
     */
    readonly bucketArn: string;
    /**
     * @stability stable
     */
    readonly fileKey: string;
    /**
     * @stability stable
     */
    readonly roleArn: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordColumns {
    /**
     * @stability stable
     */
    readonly mapping?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly sqlType: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv {
    /**
     * @stability stable
     */
    readonly recordColumnDelimiter: string;
    /**
     * @stability stable
     */
    readonly recordRowDelimiter: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson {
    /**
     * @stability stable
     */
    readonly recordRowPath: string;
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters {
    /**
     * csv block.
     *
     * @stability stable
     */
    readonly csv?: KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv[];
    /**
     * json block.
     *
     * @stability stable
     */
    readonly json?: KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormat {
    /**
     * mapping_parameters block.
     *
     * @stability stable
     */
    readonly mappingParameters?: KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationReferenceDataSourcesSchema {
    /**
     * @stability stable
     */
    readonly recordEncoding?: string;
    /**
     * record_columns block.
     *
     * @stability stable
     */
    readonly recordColumns: KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordColumns[];
    /**
     * record_format block.
     *
     * @stability stable
     */
    readonly recordFormat: KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormat[];
}
/**
 * @stability stable
 */
export interface KinesisAnalyticsApplicationReferenceDataSources {
    /**
     * @stability stable
     */
    readonly tableName: string;
    /**
     * s3 block.
     *
     * @stability stable
     */
    readonly s3: KinesisAnalyticsApplicationReferenceDataSourcesS3[];
    /**
     * schema block.
     *
     * @stability stable
     */
    readonly schema: KinesisAnalyticsApplicationReferenceDataSourcesSchema[];
}
/**
 * @stability stable
 */
export declare class KinesisAnalyticsApplication extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KinesisAnalyticsApplicationConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _code?;
    /**
     * @stability stable
     */
    get code(): string;
    /**
     * @stability stable
     */
    set code(value: string);
    /**
     * @stability stable
     */
    resetCode(): void;
    /**
     * @stability stable
     */
    get codeInput(): string | undefined;
    /**
     * @stability stable
     */
    get createTimestamp(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastUpdateTimestamp(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _startApplication?;
    /**
     * @stability stable
     */
    get startApplication(): boolean;
    /**
     * @stability stable
     */
    set startApplication(value: boolean);
    /**
     * @stability stable
     */
    resetStartApplication(): void;
    /**
     * @stability stable
     */
    get startApplicationInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get version(): number;
    private _cloudwatchLoggingOptions?;
    /**
     * @stability stable
     */
    get cloudwatchLoggingOptions(): KinesisAnalyticsApplicationCloudwatchLoggingOptions[];
    /**
     * @stability stable
     */
    set cloudwatchLoggingOptions(value: KinesisAnalyticsApplicationCloudwatchLoggingOptions[]);
    /**
     * @stability stable
     */
    resetCloudwatchLoggingOptions(): void;
    /**
     * @stability stable
     */
    get cloudwatchLoggingOptionsInput(): KinesisAnalyticsApplicationCloudwatchLoggingOptions[] | undefined;
    private _inputs?;
    /**
     * @stability stable
     */
    get inputs(): KinesisAnalyticsApplicationInputs[];
    /**
     * @stability stable
     */
    set inputs(value: KinesisAnalyticsApplicationInputs[]);
    /**
     * @stability stable
     */
    resetInputs(): void;
    /**
     * @stability stable
     */
    get inputsInput(): KinesisAnalyticsApplicationInputs[] | undefined;
    private _outputs?;
    /**
     * @stability stable
     */
    get outputs(): KinesisAnalyticsApplicationOutputs[];
    /**
     * @stability stable
     */
    set outputs(value: KinesisAnalyticsApplicationOutputs[]);
    /**
     * @stability stable
     */
    resetOutputs(): void;
    /**
     * @stability stable
     */
    get outputsInput(): KinesisAnalyticsApplicationOutputs[] | undefined;
    private _referenceDataSources?;
    /**
     * @stability stable
     */
    get referenceDataSources(): KinesisAnalyticsApplicationReferenceDataSources[];
    /**
     * @stability stable
     */
    set referenceDataSources(value: KinesisAnalyticsApplicationReferenceDataSources[]);
    /**
     * @stability stable
     */
    resetReferenceDataSources(): void;
    /**
     * @stability stable
     */
    get referenceDataSourcesInput(): KinesisAnalyticsApplicationReferenceDataSources[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
