import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface LambdaFunctionConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly codeSigningConfigArn?: string;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly filename?: string;
    /**
     * @stability stable
     */
    readonly functionName: string;
    /**
     * @stability stable
     */
    readonly handler?: string;
    /**
     * @stability stable
     */
    readonly imageUri?: string;
    /**
     * @stability stable
     */
    readonly kmsKeyArn?: string;
    /**
     * @stability stable
     */
    readonly layers?: string[];
    /**
     * @stability stable
     */
    readonly memorySize?: number;
    /**
     * @stability stable
     */
    readonly packageType?: string;
    /**
     * @stability stable
     */
    readonly publish?: boolean;
    /**
     * @stability stable
     */
    readonly reservedConcurrentExecutions?: number;
    /**
     * @stability stable
     */
    readonly role: string;
    /**
     * @stability stable
     */
    readonly runtime?: string;
    /**
     * @stability stable
     */
    readonly s3Bucket?: string;
    /**
     * @stability stable
     */
    readonly s3Key?: string;
    /**
     * @stability stable
     */
    readonly s3ObjectVersion?: string;
    /**
     * @stability stable
     */
    readonly sourceCodeHash?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * dead_letter_config block.
     *
     * @stability stable
     */
    readonly deadLetterConfig?: LambdaFunctionDeadLetterConfig[];
    /**
     * environment block.
     *
     * @stability stable
     */
    readonly environment?: LambdaFunctionEnvironment[];
    /**
     * file_system_config block.
     *
     * @stability stable
     */
    readonly fileSystemConfig?: LambdaFunctionFileSystemConfig[];
    /**
     * image_config block.
     *
     * @stability stable
     */
    readonly imageConfig?: LambdaFunctionImageConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: LambdaFunctionTimeouts;
    /**
     * tracing_config block.
     *
     * @stability stable
     */
    readonly tracingConfig?: LambdaFunctionTracingConfig[];
    /**
     * vpc_config block.
     *
     * @stability stable
     */
    readonly vpcConfig?: LambdaFunctionVpcConfig[];
}
/**
 * @stability stable
 */
export interface LambdaFunctionDeadLetterConfig {
    /**
     * @stability stable
     */
    readonly targetArn: string;
}
/**
 * @stability stable
 */
export interface LambdaFunctionEnvironment {
    /**
     * @stability stable
     */
    readonly variables?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface LambdaFunctionFileSystemConfig {
    /**
     * @stability stable
     */
    readonly arn: string;
    /**
     * @stability stable
     */
    readonly localMountPath: string;
}
/**
 * @stability stable
 */
export interface LambdaFunctionImageConfig {
    /**
     * @stability stable
     */
    readonly command?: string[];
    /**
     * @stability stable
     */
    readonly entryPoint?: string[];
    /**
     * @stability stable
     */
    readonly workingDirectory?: string;
}
/**
 * @stability stable
 */
export interface LambdaFunctionTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
}
/**
 * @stability stable
 */
export interface LambdaFunctionTracingConfig {
    /**
     * @stability stable
     */
    readonly mode: string;
}
/**
 * @stability stable
 */
export interface LambdaFunctionVpcConfig {
    /**
     * @stability stable
     */
    readonly securityGroupIds: string[];
    /**
     * @stability stable
     */
    readonly subnetIds: string[];
}
/**
 * @stability stable
 */
export declare class LambdaFunction extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LambdaFunctionConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _codeSigningConfigArn?;
    /**
     * @stability stable
     */
    get codeSigningConfigArn(): string;
    /**
     * @stability stable
     */
    set codeSigningConfigArn(value: string);
    /**
     * @stability stable
     */
    resetCodeSigningConfigArn(): void;
    /**
     * @stability stable
     */
    get codeSigningConfigArnInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _filename?;
    /**
     * @stability stable
     */
    get filename(): string;
    /**
     * @stability stable
     */
    set filename(value: string);
    /**
     * @stability stable
     */
    resetFilename(): void;
    /**
     * @stability stable
     */
    get filenameInput(): string | undefined;
    private _functionName;
    /**
     * @stability stable
     */
    get functionName(): string;
    /**
     * @stability stable
     */
    set functionName(value: string);
    /**
     * @stability stable
     */
    get functionNameInput(): string;
    private _handler?;
    /**
     * @stability stable
     */
    get handler(): string;
    /**
     * @stability stable
     */
    set handler(value: string);
    /**
     * @stability stable
     */
    resetHandler(): void;
    /**
     * @stability stable
     */
    get handlerInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _imageUri?;
    /**
     * @stability stable
     */
    get imageUri(): string;
    /**
     * @stability stable
     */
    set imageUri(value: string);
    /**
     * @stability stable
     */
    resetImageUri(): void;
    /**
     * @stability stable
     */
    get imageUriInput(): string | undefined;
    /**
     * @stability stable
     */
    get invokeArn(): string;
    private _kmsKeyArn?;
    /**
     * @stability stable
     */
    get kmsKeyArn(): string;
    /**
     * @stability stable
     */
    set kmsKeyArn(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyArn(): void;
    /**
     * @stability stable
     */
    get kmsKeyArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get lastModified(): string;
    private _layers?;
    /**
     * @stability stable
     */
    get layers(): string[];
    /**
     * @stability stable
     */
    set layers(value: string[]);
    /**
     * @stability stable
     */
    resetLayers(): void;
    /**
     * @stability stable
     */
    get layersInput(): string[] | undefined;
    private _memorySize?;
    /**
     * @stability stable
     */
    get memorySize(): number;
    /**
     * @stability stable
     */
    set memorySize(value: number);
    /**
     * @stability stable
     */
    resetMemorySize(): void;
    /**
     * @stability stable
     */
    get memorySizeInput(): number | undefined;
    private _packageType?;
    /**
     * @stability stable
     */
    get packageType(): string;
    /**
     * @stability stable
     */
    set packageType(value: string);
    /**
     * @stability stable
     */
    resetPackageType(): void;
    /**
     * @stability stable
     */
    get packageTypeInput(): string | undefined;
    private _publish?;
    /**
     * @stability stable
     */
    get publish(): boolean;
    /**
     * @stability stable
     */
    set publish(value: boolean);
    /**
     * @stability stable
     */
    resetPublish(): void;
    /**
     * @stability stable
     */
    get publishInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get qualifiedArn(): string;
    private _reservedConcurrentExecutions?;
    /**
     * @stability stable
     */
    get reservedConcurrentExecutions(): number;
    /**
     * @stability stable
     */
    set reservedConcurrentExecutions(value: number);
    /**
     * @stability stable
     */
    resetReservedConcurrentExecutions(): void;
    /**
     * @stability stable
     */
    get reservedConcurrentExecutionsInput(): number | undefined;
    private _role;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    get roleInput(): string;
    private _runtime?;
    /**
     * @stability stable
     */
    get runtime(): string;
    /**
     * @stability stable
     */
    set runtime(value: string);
    /**
     * @stability stable
     */
    resetRuntime(): void;
    /**
     * @stability stable
     */
    get runtimeInput(): string | undefined;
    private _s3Bucket?;
    /**
     * @stability stable
     */
    get s3Bucket(): string;
    /**
     * @stability stable
     */
    set s3Bucket(value: string);
    /**
     * @stability stable
     */
    resetS3Bucket(): void;
    /**
     * @stability stable
     */
    get s3BucketInput(): string | undefined;
    private _s3Key?;
    /**
     * @stability stable
     */
    get s3Key(): string;
    /**
     * @stability stable
     */
    set s3Key(value: string);
    /**
     * @stability stable
     */
    resetS3Key(): void;
    /**
     * @stability stable
     */
    get s3KeyInput(): string | undefined;
    private _s3ObjectVersion?;
    /**
     * @stability stable
     */
    get s3ObjectVersion(): string;
    /**
     * @stability stable
     */
    set s3ObjectVersion(value: string);
    /**
     * @stability stable
     */
    resetS3ObjectVersion(): void;
    /**
     * @stability stable
     */
    get s3ObjectVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get signingJobArn(): string;
    /**
     * @stability stable
     */
    get signingProfileVersionArn(): string;
    private _sourceCodeHash?;
    /**
     * @stability stable
     */
    get sourceCodeHash(): string;
    /**
     * @stability stable
     */
    set sourceCodeHash(value: string);
    /**
     * @stability stable
     */
    resetSourceCodeHash(): void;
    /**
     * @stability stable
     */
    get sourceCodeHashInput(): string | undefined;
    /**
     * @stability stable
     */
    get sourceCodeSize(): number;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _timeout?;
    /**
     * @stability stable
     */
    get timeout(): number;
    /**
     * @stability stable
     */
    set timeout(value: number);
    /**
     * @stability stable
     */
    resetTimeout(): void;
    /**
     * @stability stable
     */
    get timeoutInput(): number | undefined;
    /**
     * @stability stable
     */
    get version(): string;
    private _deadLetterConfig?;
    /**
     * @stability stable
     */
    get deadLetterConfig(): LambdaFunctionDeadLetterConfig[];
    /**
     * @stability stable
     */
    set deadLetterConfig(value: LambdaFunctionDeadLetterConfig[]);
    /**
     * @stability stable
     */
    resetDeadLetterConfig(): void;
    /**
     * @stability stable
     */
    get deadLetterConfigInput(): LambdaFunctionDeadLetterConfig[] | undefined;
    private _environment?;
    /**
     * @stability stable
     */
    get environment(): LambdaFunctionEnvironment[];
    /**
     * @stability stable
     */
    set environment(value: LambdaFunctionEnvironment[]);
    /**
     * @stability stable
     */
    resetEnvironment(): void;
    /**
     * @stability stable
     */
    get environmentInput(): LambdaFunctionEnvironment[] | undefined;
    private _fileSystemConfig?;
    /**
     * @stability stable
     */
    get fileSystemConfig(): LambdaFunctionFileSystemConfig[];
    /**
     * @stability stable
     */
    set fileSystemConfig(value: LambdaFunctionFileSystemConfig[]);
    /**
     * @stability stable
     */
    resetFileSystemConfig(): void;
    /**
     * @stability stable
     */
    get fileSystemConfigInput(): LambdaFunctionFileSystemConfig[] | undefined;
    private _imageConfig?;
    /**
     * @stability stable
     */
    get imageConfig(): LambdaFunctionImageConfig[];
    /**
     * @stability stable
     */
    set imageConfig(value: LambdaFunctionImageConfig[]);
    /**
     * @stability stable
     */
    resetImageConfig(): void;
    /**
     * @stability stable
     */
    get imageConfigInput(): LambdaFunctionImageConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): LambdaFunctionTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: LambdaFunctionTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): LambdaFunctionTimeouts | undefined;
    private _tracingConfig?;
    /**
     * @stability stable
     */
    get tracingConfig(): LambdaFunctionTracingConfig[];
    /**
     * @stability stable
     */
    set tracingConfig(value: LambdaFunctionTracingConfig[]);
    /**
     * @stability stable
     */
    resetTracingConfig(): void;
    /**
     * @stability stable
     */
    get tracingConfigInput(): LambdaFunctionTracingConfig[] | undefined;
    private _vpcConfig?;
    /**
     * @stability stable
     */
    get vpcConfig(): LambdaFunctionVpcConfig[];
    /**
     * @stability stable
     */
    set vpcConfig(value: LambdaFunctionVpcConfig[]);
    /**
     * @stability stable
     */
    resetVpcConfig(): void;
    /**
     * @stability stable
     */
    get vpcConfigInput(): LambdaFunctionVpcConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
