import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface LbListenerConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly certificateArn?: string;
    /**
     * @stability stable
     */
    readonly loadBalancerArn: string;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * @stability stable
     */
    readonly sslPolicy?: string;
    /**
     * default_action block.
     *
     * @stability stable
     */
    readonly defaultAction: LbListenerDefaultAction[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: LbListenerTimeouts;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionAuthenticateCognito {
    /**
     * @stability stable
     */
    readonly authenticationRequestExtraParams?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly onUnauthenticatedRequest?: string;
    /**
     * @stability stable
     */
    readonly scope?: string;
    /**
     * @stability stable
     */
    readonly sessionCookieName?: string;
    /**
     * @stability stable
     */
    readonly sessionTimeout?: number;
    /**
     * @stability stable
     */
    readonly userPoolArn: string;
    /**
     * @stability stable
     */
    readonly userPoolClientId: string;
    /**
     * @stability stable
     */
    readonly userPoolDomain: string;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionAuthenticateOidc {
    /**
     * @stability stable
     */
    readonly authenticationRequestExtraParams?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly authorizationEndpoint: string;
    /**
     * @stability stable
     */
    readonly clientId: string;
    /**
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * @stability stable
     */
    readonly issuer: string;
    /**
     * @stability stable
     */
    readonly onUnauthenticatedRequest?: string;
    /**
     * @stability stable
     */
    readonly scope?: string;
    /**
     * @stability stable
     */
    readonly sessionCookieName?: string;
    /**
     * @stability stable
     */
    readonly sessionTimeout?: number;
    /**
     * @stability stable
     */
    readonly tokenEndpoint: string;
    /**
     * @stability stable
     */
    readonly userInfoEndpoint: string;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionFixedResponse {
    /**
     * @stability stable
     */
    readonly contentType: string;
    /**
     * @stability stable
     */
    readonly messageBody?: string;
    /**
     * @stability stable
     */
    readonly statusCode?: string;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionForwardStickiness {
    /**
     * @stability stable
     */
    readonly duration: number;
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionForwardTargetGroup {
    /**
     * @stability stable
     */
    readonly arn: string;
    /**
     * @stability stable
     */
    readonly weight?: number;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionForward {
    /**
     * stickiness block.
     *
     * @stability stable
     */
    readonly stickiness?: LbListenerDefaultActionForwardStickiness[];
    /**
     * target_group block.
     *
     * @stability stable
     */
    readonly targetGroup: LbListenerDefaultActionForwardTargetGroup[];
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionRedirect {
    /**
     * @stability stable
     */
    readonly host?: string;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly port?: string;
    /**
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * @stability stable
     */
    readonly query?: string;
    /**
     * @stability stable
     */
    readonly statusCode: string;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultAction {
    /**
     * @stability stable
     */
    readonly order?: number;
    /**
     * @stability stable
     */
    readonly targetGroupArn?: string;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * authenticate_cognito block.
     *
     * @stability stable
     */
    readonly authenticateCognito?: LbListenerDefaultActionAuthenticateCognito[];
    /**
     * authenticate_oidc block.
     *
     * @stability stable
     */
    readonly authenticateOidc?: LbListenerDefaultActionAuthenticateOidc[];
    /**
     * fixed_response block.
     *
     * @stability stable
     */
    readonly fixedResponse?: LbListenerDefaultActionFixedResponse[];
    /**
     * forward block.
     *
     * @stability stable
     */
    readonly forward?: LbListenerDefaultActionForward[];
    /**
     * redirect block.
     *
     * @stability stable
     */
    readonly redirect?: LbListenerDefaultActionRedirect[];
}
/**
 * @stability stable
 */
export interface LbListenerTimeouts {
    /**
     * @stability stable
     */
    readonly read?: string;
}
/**
 * @stability stable
 */
export declare class LbListener extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LbListenerConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _certificateArn?;
    /**
     * @stability stable
     */
    get certificateArn(): string;
    /**
     * @stability stable
     */
    set certificateArn(value: string);
    /**
     * @stability stable
     */
    resetCertificateArn(): void;
    /**
     * @stability stable
     */
    get certificateArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _loadBalancerArn;
    /**
     * @stability stable
     */
    get loadBalancerArn(): string;
    /**
     * @stability stable
     */
    set loadBalancerArn(value: string);
    /**
     * @stability stable
     */
    get loadBalancerArnInput(): string;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
    private _protocol?;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    set protocol(value: string);
    /**
     * @stability stable
     */
    resetProtocol(): void;
    /**
     * @stability stable
     */
    get protocolInput(): string | undefined;
    private _sslPolicy?;
    /**
     * @stability stable
     */
    get sslPolicy(): string;
    /**
     * @stability stable
     */
    set sslPolicy(value: string);
    /**
     * @stability stable
     */
    resetSslPolicy(): void;
    /**
     * @stability stable
     */
    get sslPolicyInput(): string | undefined;
    private _defaultAction;
    /**
     * @stability stable
     */
    get defaultAction(): LbListenerDefaultAction[];
    /**
     * @stability stable
     */
    set defaultAction(value: LbListenerDefaultAction[]);
    /**
     * @stability stable
     */
    get defaultActionInput(): LbListenerDefaultAction[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): LbListenerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: LbListenerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): LbListenerTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
