import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MqBrokerConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly applyImmediately?: boolean;
    /**
     * @stability stable
     */
    readonly authenticationStrategy?: string;
    /**
     * @stability stable
     */
    readonly autoMinorVersionUpgrade?: boolean;
    /**
     * @stability stable
     */
    readonly brokerName: string;
    /**
     * @stability stable
     */
    readonly deploymentMode?: string;
    /**
     * @stability stable
     */
    readonly engineType: string;
    /**
     * @stability stable
     */
    readonly engineVersion: string;
    /**
     * @stability stable
     */
    readonly hostInstanceType: string;
    /**
     * @stability stable
     */
    readonly publiclyAccessible?: boolean;
    /**
     * @stability stable
     */
    readonly securityGroups?: string[];
    /**
     * @stability stable
     */
    readonly storageType?: string;
    /**
     * @stability stable
     */
    readonly subnetIds?: string[];
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * configuration block.
     *
     * @stability stable
     */
    readonly configuration?: MqBrokerConfiguration[];
    /**
     * encryption_options block.
     *
     * @stability stable
     */
    readonly encryptionOptions?: MqBrokerEncryptionOptions[];
    /**
     * ldap_server_metadata block.
     *
     * @stability stable
     */
    readonly ldapServerMetadata?: MqBrokerLdapServerMetadata[];
    /**
     * logs block.
     *
     * @stability stable
     */
    readonly logs?: MqBrokerLogs[];
    /**
     * maintenance_window_start_time block.
     *
     * @stability stable
     */
    readonly maintenanceWindowStartTime?: MqBrokerMaintenanceWindowStartTime[];
    /**
     * user block.
     *
     * @stability stable
     */
    readonly user: MqBrokerUser[];
}
/**
 * @stability stable
 */
export declare class MqBrokerInstances extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get consoleUrl(): string;
    /**
     * @stability stable
     */
    get endpoints(): string[];
    /**
     * @stability stable
     */
    get ipAddress(): string;
}
/**
 * @stability stable
 */
export interface MqBrokerConfiguration {
    /**
     * @stability stable
     */
    readonly id?: string;
    /**
     * @stability stable
     */
    readonly revision?: number;
}
/**
 * @stability stable
 */
export interface MqBrokerEncryptionOptions {
    /**
     * @stability stable
     */
    readonly kmsKeyId?: string;
    /**
     * @stability stable
     */
    readonly useAwsOwnedKey?: boolean;
}
/**
 * @stability stable
 */
export interface MqBrokerLdapServerMetadata {
    /**
     * @stability stable
     */
    readonly hosts?: string[];
    /**
     * @stability stable
     */
    readonly roleBase?: string;
    /**
     * @stability stable
     */
    readonly roleName?: string;
    /**
     * @stability stable
     */
    readonly roleSearchMatching?: string;
    /**
     * @stability stable
     */
    readonly roleSearchSubtree?: boolean;
    /**
     * @stability stable
     */
    readonly serviceAccountPassword?: string;
    /**
     * @stability stable
     */
    readonly serviceAccountUsername?: string;
    /**
     * @stability stable
     */
    readonly userBase?: string;
    /**
     * @stability stable
     */
    readonly userRoleName?: string;
    /**
     * @stability stable
     */
    readonly userSearchMatching?: string;
    /**
     * @stability stable
     */
    readonly userSearchSubtree?: boolean;
}
/**
 * @stability stable
 */
export interface MqBrokerLogs {
    /**
     * @stability stable
     */
    readonly audit?: boolean;
    /**
     * @stability stable
     */
    readonly general?: boolean;
}
/**
 * @stability stable
 */
export interface MqBrokerMaintenanceWindowStartTime {
    /**
     * @stability stable
     */
    readonly dayOfWeek: string;
    /**
     * @stability stable
     */
    readonly timeOfDay: string;
    /**
     * @stability stable
     */
    readonly timeZone: string;
}
/**
 * @stability stable
 */
export interface MqBrokerUser {
    /**
     * @stability stable
     */
    readonly consoleAccess?: boolean;
    /**
     * @stability stable
     */
    readonly groups?: string[];
    /**
     * @stability stable
     */
    readonly password: string;
    /**
     * @stability stable
     */
    readonly username: string;
}
/**
 * @stability stable
 */
export declare class MqBroker extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MqBrokerConfig);
    private _applyImmediately?;
    /**
     * @stability stable
     */
    get applyImmediately(): boolean;
    /**
     * @stability stable
     */
    set applyImmediately(value: boolean);
    /**
     * @stability stable
     */
    resetApplyImmediately(): void;
    /**
     * @stability stable
     */
    get applyImmediatelyInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _authenticationStrategy?;
    /**
     * @stability stable
     */
    get authenticationStrategy(): string;
    /**
     * @stability stable
     */
    set authenticationStrategy(value: string);
    /**
     * @stability stable
     */
    resetAuthenticationStrategy(): void;
    /**
     * @stability stable
     */
    get authenticationStrategyInput(): string | undefined;
    private _autoMinorVersionUpgrade?;
    /**
     * @stability stable
     */
    get autoMinorVersionUpgrade(): boolean;
    /**
     * @stability stable
     */
    set autoMinorVersionUpgrade(value: boolean);
    /**
     * @stability stable
     */
    resetAutoMinorVersionUpgrade(): void;
    /**
     * @stability stable
     */
    get autoMinorVersionUpgradeInput(): boolean | undefined;
    private _brokerName;
    /**
     * @stability stable
     */
    get brokerName(): string;
    /**
     * @stability stable
     */
    set brokerName(value: string);
    /**
     * @stability stable
     */
    get brokerNameInput(): string;
    private _deploymentMode?;
    /**
     * @stability stable
     */
    get deploymentMode(): string;
    /**
     * @stability stable
     */
    set deploymentMode(value: string);
    /**
     * @stability stable
     */
    resetDeploymentMode(): void;
    /**
     * @stability stable
     */
    get deploymentModeInput(): string | undefined;
    private _engineType;
    /**
     * @stability stable
     */
    get engineType(): string;
    /**
     * @stability stable
     */
    set engineType(value: string);
    /**
     * @stability stable
     */
    get engineTypeInput(): string;
    private _engineVersion;
    /**
     * @stability stable
     */
    get engineVersion(): string;
    /**
     * @stability stable
     */
    set engineVersion(value: string);
    /**
     * @stability stable
     */
    get engineVersionInput(): string;
    private _hostInstanceType;
    /**
     * @stability stable
     */
    get hostInstanceType(): string;
    /**
     * @stability stable
     */
    set hostInstanceType(value: string);
    /**
     * @stability stable
     */
    get hostInstanceTypeInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    instances(index: string): MqBrokerInstances;
    private _publiclyAccessible?;
    /**
     * @stability stable
     */
    get publiclyAccessible(): boolean;
    /**
     * @stability stable
     */
    set publiclyAccessible(value: boolean);
    /**
     * @stability stable
     */
    resetPubliclyAccessible(): void;
    /**
     * @stability stable
     */
    get publiclyAccessibleInput(): boolean | undefined;
    private _securityGroups?;
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    set securityGroups(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroups(): void;
    /**
     * @stability stable
     */
    get securityGroupsInput(): string[] | undefined;
    private _storageType?;
    /**
     * @stability stable
     */
    get storageType(): string;
    /**
     * @stability stable
     */
    set storageType(value: string);
    /**
     * @stability stable
     */
    resetStorageType(): void;
    /**
     * @stability stable
     */
    get storageTypeInput(): string | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    resetSubnetIds(): void;
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _configuration?;
    /**
     * @stability stable
     */
    get configuration(): MqBrokerConfiguration[];
    /**
     * @stability stable
     */
    set configuration(value: MqBrokerConfiguration[]);
    /**
     * @stability stable
     */
    resetConfiguration(): void;
    /**
     * @stability stable
     */
    get configurationInput(): MqBrokerConfiguration[] | undefined;
    private _encryptionOptions?;
    /**
     * @stability stable
     */
    get encryptionOptions(): MqBrokerEncryptionOptions[];
    /**
     * @stability stable
     */
    set encryptionOptions(value: MqBrokerEncryptionOptions[]);
    /**
     * @stability stable
     */
    resetEncryptionOptions(): void;
    /**
     * @stability stable
     */
    get encryptionOptionsInput(): MqBrokerEncryptionOptions[] | undefined;
    private _ldapServerMetadata?;
    /**
     * @stability stable
     */
    get ldapServerMetadata(): MqBrokerLdapServerMetadata[];
    /**
     * @stability stable
     */
    set ldapServerMetadata(value: MqBrokerLdapServerMetadata[]);
    /**
     * @stability stable
     */
    resetLdapServerMetadata(): void;
    /**
     * @stability stable
     */
    get ldapServerMetadataInput(): MqBrokerLdapServerMetadata[] | undefined;
    private _logs?;
    /**
     * @stability stable
     */
    get logs(): MqBrokerLogs[];
    /**
     * @stability stable
     */
    set logs(value: MqBrokerLogs[]);
    /**
     * @stability stable
     */
    resetLogs(): void;
    /**
     * @stability stable
     */
    get logsInput(): MqBrokerLogs[] | undefined;
    private _maintenanceWindowStartTime?;
    /**
     * @stability stable
     */
    get maintenanceWindowStartTime(): MqBrokerMaintenanceWindowStartTime[];
    /**
     * @stability stable
     */
    set maintenanceWindowStartTime(value: MqBrokerMaintenanceWindowStartTime[]);
    /**
     * @stability stable
     */
    resetMaintenanceWindowStartTime(): void;
    /**
     * @stability stable
     */
    get maintenanceWindowStartTimeInput(): MqBrokerMaintenanceWindowStartTime[] | undefined;
    private _user;
    /**
     * @stability stable
     */
    get user(): MqBrokerUser[];
    /**
     * @stability stable
     */
    set user(value: MqBrokerUser[]);
    /**
     * @stability stable
     */
    get userInput(): MqBrokerUser[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
