import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MskClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly clusterName: string;
    /**
     * @stability stable
     */
    readonly enhancedMonitoring?: string;
    /**
     * @stability stable
     */
    readonly kafkaVersion: string;
    /**
     * @stability stable
     */
    readonly numberOfBrokerNodes: number;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * broker_node_group_info block.
     *
     * @stability stable
     */
    readonly brokerNodeGroupInfo: MskClusterBrokerNodeGroupInfo[];
    /**
     * client_authentication block.
     *
     * @stability stable
     */
    readonly clientAuthentication?: MskClusterClientAuthentication[];
    /**
     * configuration_info block.
     *
     * @stability stable
     */
    readonly configurationInfo?: MskClusterConfigurationInfo[];
    /**
     * encryption_info block.
     *
     * @stability stable
     */
    readonly encryptionInfo?: MskClusterEncryptionInfo[];
    /**
     * logging_info block.
     *
     * @stability stable
     */
    readonly loggingInfo?: MskClusterLoggingInfo[];
    /**
     * open_monitoring block.
     *
     * @stability stable
     */
    readonly openMonitoring?: MskClusterOpenMonitoring[];
}
/**
 * @stability stable
 */
export interface MskClusterBrokerNodeGroupInfo {
    /**
     * @stability stable
     */
    readonly azDistribution?: string;
    /**
     * @stability stable
     */
    readonly clientSubnets: string[];
    /**
     * @stability stable
     */
    readonly ebsVolumeSize: number;
    /**
     * @stability stable
     */
    readonly instanceType: string;
    /**
     * @stability stable
     */
    readonly securityGroups: string[];
}
/**
 * @stability stable
 */
export interface MskClusterClientAuthenticationSasl {
    /**
     * @stability stable
     */
    readonly scram?: boolean;
}
/**
 * @stability stable
 */
export interface MskClusterClientAuthenticationTls {
    /**
     * @stability stable
     */
    readonly certificateAuthorityArns?: string[];
}
/**
 * @stability stable
 */
export interface MskClusterClientAuthentication {
    /**
     * sasl block.
     *
     * @stability stable
     */
    readonly sasl?: MskClusterClientAuthenticationSasl[];
    /**
     * tls block.
     *
     * @stability stable
     */
    readonly tls?: MskClusterClientAuthenticationTls[];
}
/**
 * @stability stable
 */
export interface MskClusterConfigurationInfo {
    /**
     * @stability stable
     */
    readonly arn: string;
    /**
     * @stability stable
     */
    readonly revision: number;
}
/**
 * @stability stable
 */
export interface MskClusterEncryptionInfoEncryptionInTransit {
    /**
     * @stability stable
     */
    readonly clientBroker?: string;
    /**
     * @stability stable
     */
    readonly inCluster?: boolean;
}
/**
 * @stability stable
 */
export interface MskClusterEncryptionInfo {
    /**
     * @stability stable
     */
    readonly encryptionAtRestKmsKeyArn?: string;
    /**
     * encryption_in_transit block.
     *
     * @stability stable
     */
    readonly encryptionInTransit?: MskClusterEncryptionInfoEncryptionInTransit[];
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfoBrokerLogsCloudwatchLogs {
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * @stability stable
     */
    readonly logGroup?: string;
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfoBrokerLogsFirehose {
    /**
     * @stability stable
     */
    readonly deliveryStream?: string;
    /**
     * @stability stable
     */
    readonly enabled: boolean;
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfoBrokerLogsS3 {
    /**
     * @stability stable
     */
    readonly bucket?: string;
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * @stability stable
     */
    readonly prefix?: string;
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfoBrokerLogs {
    /**
     * cloudwatch_logs block.
     *
     * @stability stable
     */
    readonly cloudwatchLogs?: MskClusterLoggingInfoBrokerLogsCloudwatchLogs[];
    /**
     * firehose block.
     *
     * @stability stable
     */
    readonly firehose?: MskClusterLoggingInfoBrokerLogsFirehose[];
    /**
     * s3 block.
     *
     * @stability stable
     */
    readonly s3?: MskClusterLoggingInfoBrokerLogsS3[];
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfo {
    /**
     * broker_logs block.
     *
     * @stability stable
     */
    readonly brokerLogs: MskClusterLoggingInfoBrokerLogs[];
}
/**
 * @stability stable
 */
export interface MskClusterOpenMonitoringPrometheusJmxExporter {
    /**
     * @stability stable
     */
    readonly enabledInBroker: boolean;
}
/**
 * @stability stable
 */
export interface MskClusterOpenMonitoringPrometheusNodeExporter {
    /**
     * @stability stable
     */
    readonly enabledInBroker: boolean;
}
/**
 * @stability stable
 */
export interface MskClusterOpenMonitoringPrometheus {
    /**
     * jmx_exporter block.
     *
     * @stability stable
     */
    readonly jmxExporter?: MskClusterOpenMonitoringPrometheusJmxExporter[];
    /**
     * node_exporter block.
     *
     * @stability stable
     */
    readonly nodeExporter?: MskClusterOpenMonitoringPrometheusNodeExporter[];
}
/**
 * @stability stable
 */
export interface MskClusterOpenMonitoring {
    /**
     * prometheus block.
     *
     * @stability stable
     */
    readonly prometheus: MskClusterOpenMonitoringPrometheus[];
}
/**
 * @stability stable
 */
export declare class MskCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MskClusterConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get bootstrapBrokers(): string;
    /**
     * @stability stable
     */
    get bootstrapBrokersSaslScram(): string;
    /**
     * @stability stable
     */
    get bootstrapBrokersTls(): string;
    private _clusterName;
    /**
     * @stability stable
     */
    get clusterName(): string;
    /**
     * @stability stable
     */
    set clusterName(value: string);
    /**
     * @stability stable
     */
    get clusterNameInput(): string;
    /**
     * @stability stable
     */
    get currentVersion(): string;
    private _enhancedMonitoring?;
    /**
     * @stability stable
     */
    get enhancedMonitoring(): string;
    /**
     * @stability stable
     */
    set enhancedMonitoring(value: string);
    /**
     * @stability stable
     */
    resetEnhancedMonitoring(): void;
    /**
     * @stability stable
     */
    get enhancedMonitoringInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kafkaVersion;
    /**
     * @stability stable
     */
    get kafkaVersion(): string;
    /**
     * @stability stable
     */
    set kafkaVersion(value: string);
    /**
     * @stability stable
     */
    get kafkaVersionInput(): string;
    private _numberOfBrokerNodes;
    /**
     * @stability stable
     */
    get numberOfBrokerNodes(): number;
    /**
     * @stability stable
     */
    set numberOfBrokerNodes(value: number);
    /**
     * @stability stable
     */
    get numberOfBrokerNodesInput(): number;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get zookeeperConnectString(): string;
    private _brokerNodeGroupInfo;
    /**
     * @stability stable
     */
    get brokerNodeGroupInfo(): MskClusterBrokerNodeGroupInfo[];
    /**
     * @stability stable
     */
    set brokerNodeGroupInfo(value: MskClusterBrokerNodeGroupInfo[]);
    /**
     * @stability stable
     */
    get brokerNodeGroupInfoInput(): MskClusterBrokerNodeGroupInfo[];
    private _clientAuthentication?;
    /**
     * @stability stable
     */
    get clientAuthentication(): MskClusterClientAuthentication[];
    /**
     * @stability stable
     */
    set clientAuthentication(value: MskClusterClientAuthentication[]);
    /**
     * @stability stable
     */
    resetClientAuthentication(): void;
    /**
     * @stability stable
     */
    get clientAuthenticationInput(): MskClusterClientAuthentication[] | undefined;
    private _configurationInfo?;
    /**
     * @stability stable
     */
    get configurationInfo(): MskClusterConfigurationInfo[];
    /**
     * @stability stable
     */
    set configurationInfo(value: MskClusterConfigurationInfo[]);
    /**
     * @stability stable
     */
    resetConfigurationInfo(): void;
    /**
     * @stability stable
     */
    get configurationInfoInput(): MskClusterConfigurationInfo[] | undefined;
    private _encryptionInfo?;
    /**
     * @stability stable
     */
    get encryptionInfo(): MskClusterEncryptionInfo[];
    /**
     * @stability stable
     */
    set encryptionInfo(value: MskClusterEncryptionInfo[]);
    /**
     * @stability stable
     */
    resetEncryptionInfo(): void;
    /**
     * @stability stable
     */
    get encryptionInfoInput(): MskClusterEncryptionInfo[] | undefined;
    private _loggingInfo?;
    /**
     * @stability stable
     */
    get loggingInfo(): MskClusterLoggingInfo[];
    /**
     * @stability stable
     */
    set loggingInfo(value: MskClusterLoggingInfo[]);
    /**
     * @stability stable
     */
    resetLoggingInfo(): void;
    /**
     * @stability stable
     */
    get loggingInfoInput(): MskClusterLoggingInfo[] | undefined;
    private _openMonitoring?;
    /**
     * @stability stable
     */
    get openMonitoring(): MskClusterOpenMonitoring[];
    /**
     * @stability stable
     */
    set openMonitoring(value: MskClusterOpenMonitoring[]);
    /**
     * @stability stable
     */
    resetOpenMonitoring(): void;
    /**
     * @stability stable
     */
    get openMonitoringInput(): MskClusterOpenMonitoring[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
