import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface S3BucketConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly accelerationStatus?: string;
    /**
     * @stability stable
     */
    readonly acl?: string;
    /**
     * @stability stable
     */
    readonly bucket?: string;
    /**
     * @stability stable
     */
    readonly bucketPrefix?: string;
    /**
     * @stability stable
     */
    readonly forceDestroy?: boolean;
    /**
     * @stability stable
     */
    readonly hostedZoneId?: string;
    /**
     * @stability stable
     */
    readonly policy?: string;
    /**
     * @stability stable
     */
    readonly requestPayer?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly websiteDomain?: string;
    /**
     * @stability stable
     */
    readonly websiteEndpoint?: string;
    /**
     * cors_rule block.
     *
     * @stability stable
     */
    readonly corsRule?: S3BucketCorsRule[];
    /**
     * grant block.
     *
     * @stability stable
     */
    readonly grant?: S3BucketGrant[];
    /**
     * lifecycle_rule block.
     *
     * @stability stable
     */
    readonly lifecycleRule?: S3BucketLifecycleRule[];
    /**
     * logging block.
     *
     * @stability stable
     */
    readonly logging?: S3BucketLogging[];
    /**
     * object_lock_configuration block.
     *
     * @stability stable
     */
    readonly objectLockConfiguration?: S3BucketObjectLockConfiguration[];
    /**
     * replication_configuration block.
     *
     * @stability stable
     */
    readonly replicationConfiguration?: S3BucketReplicationConfiguration[];
    /**
     * server_side_encryption_configuration block.
     *
     * @stability stable
     */
    readonly serverSideEncryptionConfiguration?: S3BucketServerSideEncryptionConfiguration[];
    /**
     * versioning block.
     *
     * @stability stable
     */
    readonly versioning?: S3BucketVersioning[];
    /**
     * website block.
     *
     * @stability stable
     */
    readonly website?: S3BucketWebsite[];
}
/**
 * @stability stable
 */
export interface S3BucketCorsRule {
    /**
     * @stability stable
     */
    readonly allowedHeaders?: string[];
    /**
     * @stability stable
     */
    readonly allowedMethods: string[];
    /**
     * @stability stable
     */
    readonly allowedOrigins: string[];
    /**
     * @stability stable
     */
    readonly exposeHeaders?: string[];
    /**
     * @stability stable
     */
    readonly maxAgeSeconds?: number;
}
/**
 * @stability stable
 */
export interface S3BucketGrant {
    /**
     * @stability stable
     */
    readonly id?: string;
    /**
     * @stability stable
     */
    readonly permissions: string[];
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * @stability stable
     */
    readonly uri?: string;
}
/**
 * @stability stable
 */
export interface S3BucketLifecycleRuleExpiration {
    /**
     * @stability stable
     */
    readonly date?: string;
    /**
     * @stability stable
     */
    readonly days?: number;
    /**
     * @stability stable
     */
    readonly expiredObjectDeleteMarker?: boolean;
}
/**
 * @stability stable
 */
export interface S3BucketLifecycleRuleNoncurrentVersionExpiration {
    /**
     * @stability stable
     */
    readonly days?: number;
}
/**
 * @stability stable
 */
export interface S3BucketLifecycleRuleNoncurrentVersionTransition {
    /**
     * @stability stable
     */
    readonly days?: number;
    /**
     * @stability stable
     */
    readonly storageClass: string;
}
/**
 * @stability stable
 */
export interface S3BucketLifecycleRuleTransition {
    /**
     * @stability stable
     */
    readonly date?: string;
    /**
     * @stability stable
     */
    readonly days?: number;
    /**
     * @stability stable
     */
    readonly storageClass: string;
}
/**
 * @stability stable
 */
export interface S3BucketLifecycleRule {
    /**
     * @stability stable
     */
    readonly abortIncompleteMultipartUploadDays?: number;
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * @stability stable
     */
    readonly id?: string;
    /**
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * expiration block.
     *
     * @stability stable
     */
    readonly expiration?: S3BucketLifecycleRuleExpiration[];
    /**
     * noncurrent_version_expiration block.
     *
     * @stability stable
     */
    readonly noncurrentVersionExpiration?: S3BucketLifecycleRuleNoncurrentVersionExpiration[];
    /**
     * noncurrent_version_transition block.
     *
     * @stability stable
     */
    readonly noncurrentVersionTransition?: S3BucketLifecycleRuleNoncurrentVersionTransition[];
    /**
     * transition block.
     *
     * @stability stable
     */
    readonly transition?: S3BucketLifecycleRuleTransition[];
}
/**
 * @stability stable
 */
export interface S3BucketLogging {
    /**
     * @stability stable
     */
    readonly targetBucket: string;
    /**
     * @stability stable
     */
    readonly targetPrefix?: string;
}
/**
 * @stability stable
 */
export interface S3BucketObjectLockConfigurationRuleDefaultRetention {
    /**
     * @stability stable
     */
    readonly days?: number;
    /**
     * @stability stable
     */
    readonly mode: string;
    /**
     * @stability stable
     */
    readonly years?: number;
}
/**
 * @stability stable
 */
export interface S3BucketObjectLockConfigurationRule {
    /**
     * default_retention block.
     *
     * @stability stable
     */
    readonly defaultRetention: S3BucketObjectLockConfigurationRuleDefaultRetention[];
}
/**
 * @stability stable
 */
export interface S3BucketObjectLockConfiguration {
    /**
     * @stability stable
     */
    readonly objectLockEnabled: string;
    /**
     * rule block.
     *
     * @stability stable
     */
    readonly rule?: S3BucketObjectLockConfigurationRule[];
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation {
    /**
     * @stability stable
     */
    readonly owner: string;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesDestination {
    /**
     * @stability stable
     */
    readonly accountId?: string;
    /**
     * @stability stable
     */
    readonly bucket: string;
    /**
     * @stability stable
     */
    readonly replicaKmsKeyId?: string;
    /**
     * @stability stable
     */
    readonly storageClass?: string;
    /**
     * access_control_translation block.
     *
     * @stability stable
     */
    readonly accessControlTranslation?: S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation[];
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesFilter {
    /**
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects {
    /**
     * @stability stable
     */
    readonly enabled: boolean;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesSourceSelectionCriteria {
    /**
     * sse_kms_encrypted_objects block.
     *
     * @stability stable
     */
    readonly sseKmsEncryptedObjects?: S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects[];
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRules {
    /**
     * @stability stable
     */
    readonly id?: string;
    /**
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * @stability stable
     */
    readonly priority?: number;
    /**
     * @stability stable
     */
    readonly status: string;
    /**
     * destination block.
     *
     * @stability stable
     */
    readonly destination: S3BucketReplicationConfigurationRulesDestination[];
    /**
     * filter block.
     *
     * @stability stable
     */
    readonly filter?: S3BucketReplicationConfigurationRulesFilter[];
    /**
     * source_selection_criteria block.
     *
     * @stability stable
     */
    readonly sourceSelectionCriteria?: S3BucketReplicationConfigurationRulesSourceSelectionCriteria[];
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfiguration {
    /**
     * @stability stable
     */
    readonly role: string;
    /**
     * rules block.
     *
     * @stability stable
     */
    readonly rules: S3BucketReplicationConfigurationRules[];
}
/**
 * @stability stable
 */
export interface S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault {
    /**
     * @stability stable
     */
    readonly kmsMasterKeyId?: string;
    /**
     * @stability stable
     */
    readonly sseAlgorithm: string;
}
/**
 * @stability stable
 */
export interface S3BucketServerSideEncryptionConfigurationRule {
    /**
     * apply_server_side_encryption_by_default block.
     *
     * @stability stable
     */
    readonly applyServerSideEncryptionByDefault: S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault[];
}
/**
 * @stability stable
 */
export interface S3BucketServerSideEncryptionConfiguration {
    /**
     * rule block.
     *
     * @stability stable
     */
    readonly rule: S3BucketServerSideEncryptionConfigurationRule[];
}
/**
 * @stability stable
 */
export interface S3BucketVersioning {
    /**
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * @stability stable
     */
    readonly mfaDelete?: boolean;
}
/**
 * @stability stable
 */
export interface S3BucketWebsite {
    /**
     * @stability stable
     */
    readonly errorDocument?: string;
    /**
     * @stability stable
     */
    readonly indexDocument?: string;
    /**
     * @stability stable
     */
    readonly redirectAllRequestsTo?: string;
    /**
     * @stability stable
     */
    readonly routingRules?: string;
}
/**
 * @stability stable
 */
export declare class S3Bucket extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: S3BucketConfig);
    private _accelerationStatus?;
    /**
     * @stability stable
     */
    get accelerationStatus(): string;
    /**
     * @stability stable
     */
    set accelerationStatus(value: string);
    /**
     * @stability stable
     */
    resetAccelerationStatus(): void;
    /**
     * @stability stable
     */
    get accelerationStatusInput(): string | undefined;
    private _acl?;
    /**
     * @stability stable
     */
    get acl(): string;
    /**
     * @stability stable
     */
    set acl(value: string);
    /**
     * @stability stable
     */
    resetAcl(): void;
    /**
     * @stability stable
     */
    get aclInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    resetBucket(): void;
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    /**
     * @stability stable
     */
    get bucketDomainName(): string;
    private _bucketPrefix?;
    /**
     * @stability stable
     */
    get bucketPrefix(): string;
    /**
     * @stability stable
     */
    set bucketPrefix(value: string);
    /**
     * @stability stable
     */
    resetBucketPrefix(): void;
    /**
     * @stability stable
     */
    get bucketPrefixInput(): string | undefined;
    /**
     * @stability stable
     */
    get bucketRegionalDomainName(): string;
    private _forceDestroy?;
    /**
     * @stability stable
     */
    get forceDestroy(): boolean;
    /**
     * @stability stable
     */
    set forceDestroy(value: boolean);
    /**
     * @stability stable
     */
    resetForceDestroy(): void;
    /**
     * @stability stable
     */
    get forceDestroyInput(): boolean | undefined;
    private _hostedZoneId?;
    /**
     * @stability stable
     */
    get hostedZoneId(): string;
    /**
     * @stability stable
     */
    set hostedZoneId(value: string);
    /**
     * @stability stable
     */
    resetHostedZoneId(): void;
    /**
     * @stability stable
     */
    get hostedZoneIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _policy?;
    /**
     * @stability stable
     */
    get policy(): string;
    /**
     * @stability stable
     */
    set policy(value: string);
    /**
     * @stability stable
     */
    resetPolicy(): void;
    /**
     * @stability stable
     */
    get policyInput(): string | undefined;
    /**
     * @stability stable
     */
    get region(): string;
    private _requestPayer?;
    /**
     * @stability stable
     */
    get requestPayer(): string;
    /**
     * @stability stable
     */
    set requestPayer(value: string);
    /**
     * @stability stable
     */
    resetRequestPayer(): void;
    /**
     * @stability stable
     */
    get requestPayerInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _websiteDomain?;
    /**
     * @stability stable
     */
    get websiteDomain(): string;
    /**
     * @stability stable
     */
    set websiteDomain(value: string);
    /**
     * @stability stable
     */
    resetWebsiteDomain(): void;
    /**
     * @stability stable
     */
    get websiteDomainInput(): string | undefined;
    private _websiteEndpoint?;
    /**
     * @stability stable
     */
    get websiteEndpoint(): string;
    /**
     * @stability stable
     */
    set websiteEndpoint(value: string);
    /**
     * @stability stable
     */
    resetWebsiteEndpoint(): void;
    /**
     * @stability stable
     */
    get websiteEndpointInput(): string | undefined;
    private _corsRule?;
    /**
     * @stability stable
     */
    get corsRule(): S3BucketCorsRule[];
    /**
     * @stability stable
     */
    set corsRule(value: S3BucketCorsRule[]);
    /**
     * @stability stable
     */
    resetCorsRule(): void;
    /**
     * @stability stable
     */
    get corsRuleInput(): S3BucketCorsRule[] | undefined;
    private _grant?;
    /**
     * @stability stable
     */
    get grant(): S3BucketGrant[];
    /**
     * @stability stable
     */
    set grant(value: S3BucketGrant[]);
    /**
     * @stability stable
     */
    resetGrant(): void;
    /**
     * @stability stable
     */
    get grantInput(): S3BucketGrant[] | undefined;
    private _lifecycleRule?;
    /**
     * @stability stable
     */
    get lifecycleRule(): S3BucketLifecycleRule[];
    /**
     * @stability stable
     */
    set lifecycleRule(value: S3BucketLifecycleRule[]);
    /**
     * @stability stable
     */
    resetLifecycleRule(): void;
    /**
     * @stability stable
     */
    get lifecycleRuleInput(): S3BucketLifecycleRule[] | undefined;
    private _logging?;
    /**
     * @stability stable
     */
    get logging(): S3BucketLogging[];
    /**
     * @stability stable
     */
    set logging(value: S3BucketLogging[]);
    /**
     * @stability stable
     */
    resetLogging(): void;
    /**
     * @stability stable
     */
    get loggingInput(): S3BucketLogging[] | undefined;
    private _objectLockConfiguration?;
    /**
     * @stability stable
     */
    get objectLockConfiguration(): S3BucketObjectLockConfiguration[];
    /**
     * @stability stable
     */
    set objectLockConfiguration(value: S3BucketObjectLockConfiguration[]);
    /**
     * @stability stable
     */
    resetObjectLockConfiguration(): void;
    /**
     * @stability stable
     */
    get objectLockConfigurationInput(): S3BucketObjectLockConfiguration[] | undefined;
    private _replicationConfiguration?;
    /**
     * @stability stable
     */
    get replicationConfiguration(): S3BucketReplicationConfiguration[];
    /**
     * @stability stable
     */
    set replicationConfiguration(value: S3BucketReplicationConfiguration[]);
    /**
     * @stability stable
     */
    resetReplicationConfiguration(): void;
    /**
     * @stability stable
     */
    get replicationConfigurationInput(): S3BucketReplicationConfiguration[] | undefined;
    private _serverSideEncryptionConfiguration?;
    /**
     * @stability stable
     */
    get serverSideEncryptionConfiguration(): S3BucketServerSideEncryptionConfiguration[];
    /**
     * @stability stable
     */
    set serverSideEncryptionConfiguration(value: S3BucketServerSideEncryptionConfiguration[]);
    /**
     * @stability stable
     */
    resetServerSideEncryptionConfiguration(): void;
    /**
     * @stability stable
     */
    get serverSideEncryptionConfigurationInput(): S3BucketServerSideEncryptionConfiguration[] | undefined;
    private _versioning?;
    /**
     * @stability stable
     */
    get versioning(): S3BucketVersioning[];
    /**
     * @stability stable
     */
    set versioning(value: S3BucketVersioning[]);
    /**
     * @stability stable
     */
    resetVersioning(): void;
    /**
     * @stability stable
     */
    get versioningInput(): S3BucketVersioning[] | undefined;
    private _website?;
    /**
     * @stability stable
     */
    get website(): S3BucketWebsite[];
    /**
     * @stability stable
     */
    set website(value: S3BucketWebsite[]);
    /**
     * @stability stable
     */
    resetWebsite(): void;
    /**
     * @stability stable
     */
    get websiteInput(): S3BucketWebsite[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
