import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface WorkspacesDirectoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly directoryId: string;
    /**
     * @stability stable
     */
    readonly ipGroupIds?: string[];
    /**
     * @stability stable
     */
    readonly subnetIds?: string[];
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * self_service_permissions block.
     *
     * @stability stable
     */
    readonly selfServicePermissions?: WorkspacesDirectorySelfServicePermissions[];
    /**
     * workspace_access_properties block.
     *
     * @stability stable
     */
    readonly workspaceAccessProperties?: WorkspacesDirectoryWorkspaceAccessProperties[];
    /**
     * workspace_creation_properties block.
     *
     * @stability stable
     */
    readonly workspaceCreationProperties?: WorkspacesDirectoryWorkspaceCreationProperties[];
}
/**
 * @stability stable
 */
export interface WorkspacesDirectorySelfServicePermissions {
    /**
     * @stability stable
     */
    readonly changeComputeType?: boolean;
    /**
     * @stability stable
     */
    readonly increaseVolumeSize?: boolean;
    /**
     * @stability stable
     */
    readonly rebuildWorkspace?: boolean;
    /**
     * @stability stable
     */
    readonly restartWorkspace?: boolean;
    /**
     * @stability stable
     */
    readonly switchRunningMode?: boolean;
}
/**
 * @stability stable
 */
export interface WorkspacesDirectoryWorkspaceAccessProperties {
    /**
     * @stability stable
     */
    readonly deviceTypeAndroid?: string;
    /**
     * @stability stable
     */
    readonly deviceTypeChromeos?: string;
    /**
     * @stability stable
     */
    readonly deviceTypeIos?: string;
    /**
     * @stability stable
     */
    readonly deviceTypeOsx?: string;
    /**
     * @stability stable
     */
    readonly deviceTypeWeb?: string;
    /**
     * @stability stable
     */
    readonly deviceTypeWindows?: string;
    /**
     * @stability stable
     */
    readonly deviceTypeZeroclient?: string;
}
/**
 * @stability stable
 */
export interface WorkspacesDirectoryWorkspaceCreationProperties {
    /**
     * @stability stable
     */
    readonly customSecurityGroupId?: string;
    /**
     * @stability stable
     */
    readonly defaultOu?: string;
    /**
     * @stability stable
     */
    readonly enableInternetAccess?: boolean;
    /**
     * @stability stable
     */
    readonly enableMaintenanceMode?: boolean;
    /**
     * @stability stable
     */
    readonly userEnabledAsLocalAdministrator?: boolean;
}
/**
 * @stability stable
 */
export declare class WorkspacesDirectory extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WorkspacesDirectoryConfig);
    /**
     * @stability stable
     */
    get alias(): string;
    /**
     * @stability stable
     */
    get customerUserName(): string;
    private _directoryId;
    /**
     * @stability stable
     */
    get directoryId(): string;
    /**
     * @stability stable
     */
    set directoryId(value: string);
    /**
     * @stability stable
     */
    get directoryIdInput(): string;
    /**
     * @stability stable
     */
    get directoryName(): string;
    /**
     * @stability stable
     */
    get directoryType(): string;
    /**
     * @stability stable
     */
    get dnsIpAddresses(): string[];
    /**
     * @stability stable
     */
    get iamRoleId(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipGroupIds?;
    /**
     * @stability stable
     */
    get ipGroupIds(): string[];
    /**
     * @stability stable
     */
    set ipGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetIpGroupIds(): void;
    /**
     * @stability stable
     */
    get ipGroupIdsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get registrationCode(): string;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    resetSubnetIds(): void;
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get workspaceSecurityGroupId(): string;
    private _selfServicePermissions?;
    /**
     * @stability stable
     */
    get selfServicePermissions(): WorkspacesDirectorySelfServicePermissions[];
    /**
     * @stability stable
     */
    set selfServicePermissions(value: WorkspacesDirectorySelfServicePermissions[]);
    /**
     * @stability stable
     */
    resetSelfServicePermissions(): void;
    /**
     * @stability stable
     */
    get selfServicePermissionsInput(): WorkspacesDirectorySelfServicePermissions[] | undefined;
    private _workspaceAccessProperties?;
    /**
     * @stability stable
     */
    get workspaceAccessProperties(): WorkspacesDirectoryWorkspaceAccessProperties[];
    /**
     * @stability stable
     */
    set workspaceAccessProperties(value: WorkspacesDirectoryWorkspaceAccessProperties[]);
    /**
     * @stability stable
     */
    resetWorkspaceAccessProperties(): void;
    /**
     * @stability stable
     */
    get workspaceAccessPropertiesInput(): WorkspacesDirectoryWorkspaceAccessProperties[] | undefined;
    private _workspaceCreationProperties?;
    /**
     * @stability stable
     */
    get workspaceCreationProperties(): WorkspacesDirectoryWorkspaceCreationProperties[];
    /**
     * @stability stable
     */
    set workspaceCreationProperties(value: WorkspacesDirectoryWorkspaceCreationProperties[]);
    /**
     * @stability stable
     */
    resetWorkspaceCreationProperties(): void;
    /**
     * @stability stable
     */
    get workspaceCreationPropertiesInput(): WorkspacesDirectoryWorkspaceCreationProperties[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
